### francais.tcl:

# French language support for Scid.
# Translations contributed by:
# Gilles Maire, Vincent Serisier, Joel Rivat, Pascal Heisel, Dale J.H Cannon and Francois Paget

# Untranslated messages are marked with a "TODO To be translated" comment.

addLanguage F Francais 0 iso8859-1

proc setLanguage_F {} {

# File menu:
menuText F File "Fichier" 0
menuText F FileNew "Nouvelle..." 0 {Crer une nouvelle base de donnes Scid}
menuText F FileOpen "Ouvrir..." 0 {Ouvrir une base de donnes Scid existante}
menuText F FileClose "Fermer" 0 {Fermer la base de donnes Scid active}
menuText F FileFinder "Trouver" 0 {Ouvrir la fentre de recherche de fichier}
menuText F FileSavePgn "Save Pgn..." 0 {}
menuText F FileOpenBaseAsTree "Ouvrir base dans arbre" 0   {Ouvrir une base dans la fentre d'arbre}
menuText F FileOpenRecentBaseAsTree "Ouvrir base rcente dans arbre" 0   {Ouvrir une base rcente dans la fentre d'arbre}
menuText F FileBookmarks "Signets" 0 {Menu des signets (raccourci: Ctrl+B)}
menuText F FileBookmarksAdd "Ajouter un signet" 0 \
  {Poser un signet pour la position et partie courante}
menuText F FileBookmarksFile "Classer un signet" 0 \
  {Classer un signet pour la position et partie courante}
menuText F FileBookmarksEdit "Modifier les signets..." 0 \
  {Modifier les menus de signets}
menuText F FileBookmarksList "Afficher les dossiers comme une simple liste" 0 \
  {Afficher les dossiers comme une simple liste et non comme des sous-menus}
menuText F FileBookmarksSub "Afficher les dossiers comme des sous-menus" 0 \
  {Afficher les dossiers comme des sous-menus et non comme une simple liste}
menuText F FileReadOnly "Lecture seule..." 0 \
  {Traiter la base courante en lecture seule, en empchant les changements}
menuText F FileSwitch "Changer de base" 0 \
  {Changer vers une base ouverte diffrente}
menuText F FileExit "Quitter" 0 {Quitter Scid}

# Edit menu:
menuText F Edit "diter" 0
menuText F EditAdd "Ajouter variante" 0 {Ajouter une variante}
menuText F EditPasteVar "Coller variante" 0
menuText F EditDelete "Effacer variante" 0 {Effacer cette variante}
menuText F EditDeleteComment "Effacer les commentaires" 0
menuText F EditFirst "Dplacer en tte" 0 \
  {Dplacer cette variante en tte de liste}
menuText F EditMain "Variante vers ligne principale" 13 \
   {Promouvoir une variante en ligne principale}
menuText F EditTrial "Essayer une variante" 0 \
  {Dmarrer/Stopper mode d'essai, pour tester une ide sur l'chiquier}
menuText F EditStrip "purer" 2 {purer les commentaires ou les variantes de cette partie}
menuText F EditUndo "Annuler" 0 {Annuler la dernire modification de la partie}
menuText F EditRedo "Refaire" 0
menuText F EditStripComments "Commentaires" 0 \
  {purer cette partie de tous les commentaires et annotations}
menuText F EditStripVars "Variantes" 0 {purer cette partie des variantes}
menuText F EditStripBegin "Coups depuis le dbut" 1 \
  {purer cette partie des coups depuis le dbut}
menuText F EditStripEnd "Coups jusqu' la fin" 0 \
  {purer cette partie des coups jusqu' la fin}
menuText F EditReset "Vider le presse-papier" 0 {Vider le presse-papier}
menuText F EditCopy "Copier dans le presse-papier" 0 \
  {Copier la partie en cours dans le presse-papier}
menuText F EditPaste "Coller depuis le presse-papier" 1 \
  {Copier la partie contenue dans le presse-papier  cet emplacement}
menuText F EditPastePGN "Coller le presse-papier comme partie PGN..." 10 \
  {Interprter le texte du presse-papiers comme de la notation PGN et le coller ici}
menuText F EditSetup "Position de dpart" 0 \
  {Choisir une position de dpart pour cette partie}
menuText F EditCopyBoard "Copier la position" 6 \
  {Copier la position en cours en notation FEN vers la slection de texte (presse-papier)}
menuText F EditCopyPGN "Copier PGN" 0 {}
menuText F EditPasteBoard "Coller la position de dpart" 12 \
  {Initialiser la position de dpart  partir de la slection de texte courante(presse-papier)}

# Game menu:
menuText F Game "Partie" 0
menuText F GameNew "Nouvelle partie" 2 \
  {Remettre  zro la partie}
menuText F GameFirst "Charger la premire partie" 5 {Charger la premire partie du filtre}
menuText F GamePrev "Partie prcdente" 7 \
  {Charger la partie prcdente du filtre}
menuText F GameReload "Recharger la partie" 2 \
  {Recharger la partie (les modifications ne seront pas sauvegardes)}
menuText F GameNext "Partie suivante" 7 {Charger la partie suivante du filtre}
menuText F GameLast "Charger la dernire partie" 5 {Charger la dernire partie du filtre}
menuText F GameRandom "Charger une partie au hasard" 8 {Charger au hasard une partie du filtre}
menuText F GameNumber "Partie numro..." 9 \
  {Charger une partie en donnant son numro}
menuText F GameReplace "Enregistrer: Remplacer la partie..." 13 \
  {Enregistrer cette partie, en crasant l'ancienne version}
menuText F GameAdd "Enregistrer: Ajouter nouvelle partie..." 13 \
  {Enregistrer cette partie en tant que nouvelle partie dans la base}
menuText F GameInfo "Informations sur les jeux Set" 0
menuText F GameBrowse "Parcourir les jeux" 0
menuText F GameList "Liste Tous les jeux" 0
menuText F GameDelete "Effacer la partie" 0
menuText F GameDeepest "Identifier ouverture" 11 \
  {Trouver la partie la plus proche dans la nomenclature ECO}
menuText F GameGotoMove "Coup numro..." 6 \
  {Aller au coup spcifi dans la partie en cours}
menuText F GameNovelty "Trouver la nouveaut..." 7 \
  {Trouver le premier coup de la partie qui n'a pas t jou auparavant}

# Search menu:
menuText F Search "Rechercher" 0
menuText F SearchReset "Rinitialiser le filtre" 0 \
  {Remettre  zro le filtre (inclusion de toutes les parties)}
menuText F SearchNegate "Inverser le filtre" 0 {Inverser le filtre}
menuText F SearchEnd "Dplacer vers le dernier filtre" 0
menuText F SearchCurrent "Position..." 0 \
  {Rechercher la position en cours}
menuText F SearchHeader "Entte..." 0 \
  {Rechercher par entte (joueur, tournoi, etc) information}
menuText F SearchMaterial "Motifs" 0 \
  {Rechercher des motifs ou un matriel particulier sur l'chiquier}
menuText F SearchMoves {Coups} 0 {}
menuText F SearchUsing "En utilisant un fichier d'options..." 0 \
  {Rechercher en utilisant un fichier d'options de recherche}

# Windows menu:
menuText F Windows "Fentres" 2
menuText F WindowsGameinfo {Montrer le panneau d'info} 0 {Montrer le panneau d'info}
menuText F WindowsComment "diteur de commentaires" 0 \
  {Ouvrir/fermer l'diteur de commentaires}
menuText F WindowsGList "Liste des parties" 0 \
  {Ouvrir/fermer la liste des parties}
menuText F WindowsPGN "Fentre PGN" 8 {Ouvrir/fermer la fentre PGN}
menuText F WindowsCross "Classement du tournoi" 0 {Montrer le classement du tournoi}
menuText F WindowsPList "Chercher un joueur" 2 {Ouvrir/fermer la recherche de joueur}
menuText F WindowsTmt "Recherche de tournois" 0 {Ouvrir/fermer la recherche de tournois}
menuText F WindowsSwitcher "Changer de base" 0 \
  {Ouvrir/Fermer l'outil de changement de base}
menuText F WindowsMaint "Fentre de Maintenance" 0 \
  {Ouvrir/Fermer la fentre de maintenance}
menuText F WindowsECO "Navigateur ECO" 0 {Ouvrir/fermer le navigateur ECO}
menuText F WindowsStats "Fentre de statistique" 11 \
  {Ouvrir/Fermer le filtre de statistiques}
menuText F WindowsTree "Fentre d'arbre" 10 \
  {Ouvrir/Fermer la fentre d'arbre}
menuText F WindowsTB "Fentre de tables de finales" 8 \
  {Ouvrir/Fermer la fentre de tables de finales}
menuText F WindowsBook "Bibliothque d'ouvertures" 0 {Ouvrir/Fermer la bibliothque d'ouverture}
menuText F WindowsCorrChess "Jeu par correspondance" 0 {Ouvrir/Fermer la fentre de jeu par correspondance}

# Tools menu:
menuText F Tools "Outils" 2
menuText F ToolsAnalysis "Moteur d'analyse..." 9 \
  {Dmarrer/Arrter un moteur d'analyses}
menuText F ToolsEmail "Gestion des messages" 0 \
  {Ouvrir/Fermer la fentre de gestion des messages lectroniques}
menuText F ToolsFilterGraph "Graphique de filtre" 7 {Ouvrir/Fermer la fentre du graphique de filtre}
menuText F ToolsAbsFilterGraph "Graphique de filtre absolu" 7 {Ouvrir/Fermer la fentre du graphique de filtre absolu}
menuText F ToolsOpReport "Rapport d'ouverture" 0 {Gnrer un rapport d'ouvertures  partir de la position courante}
menuText F ToolsTracker "Suivi de pice"  0 {Ouvrir la fentre de suivi de pice}
menuText F ToolsTraining "Entrainement"  0 {Entrainement (tactique, ouvertures, ...) }
menuText F ToolsComp "Tournoi" 2 {Tournoi entre moteurs d'analyse}
menuText F ToolsTacticalGame "Partie tactique"  0 {Jouer une partie tactique}
menuText F ToolsSeriousGame "Partie srieuse"  0 {Jouer une partie sans handicap}
menuText F ToolsTrainTactics "Tactique"  0 {Rsoudre des problmes tactiques}
menuText F ToolsTrainCalvar "Calcul de variantes"  0 {Entrainement au calcul de variantes}
menuText F ToolsTrainFindBestMove "Trouver le meilleur coup"  0 {Trouver le meilleur coup}
menuText F ToolsTrainFics "Jouer sur internet"  0 {Jouer sur freechess.org}
menuText F ToolsBookTuning "Config. bibliothque" 0 {Configuration fine d'une bibliothque}
menuText F ToolsMaint "Maintenance" 0 {Maintenance de la base}
menuText F ToolsMaintWin "Fentre de maintenance" 0 \
  {Ouvrir/Fermer la fentre de maintenance}
menuText F ToolsMaintExtra "Marqueur supplmentaire" 0 {Extra Tags}
menuText F ToolsMaintCompact "Compacter la base..." 0 \
  {Compacter la base: supprimer les parties effaces et les noms non utiliss}
menuText F ToolsMaintClass "Classer les parties suivant ECO" 2 \
  {Recalculer le code ECO de toutes les parties}
menuText F ToolsMaintSort "Trier la base..." 0 {Trier toutes les parties de la base}
menuText F ToolsMaintDelete "Purger les doublons..." 0 \
  {Trouver les parties en doublons et les marquer pour l'effacement}
menuText F ToolsMaintTwin "Trouver les doublons" 0 \
  {Ouvrir/Actualiser la fentre de recherche de doublons}
menuText F ToolsMaintNameEditor "diteur de noms" 11 {Ouvrir/Fermer l'diteur de noms}
menuText F ToolsMaintNamePlayer "Corriger les noms de joueurs..." 21 \
  {Vrifier l'orthographe des noms de joueurs}
menuText F ToolsMaintNameEvent "Corriger les vnements..." 14 \
  {Vrifier l'orthographe des noms d'vnements}
menuText F ToolsMaintNameSite "Corriger les noms de lieux.." 21 \
  {Vrifier l'orthographe des noms de lieux}
menuText F ToolsMaintNameRound "Corriger les noms des rondes..." 22 \
  {Vrifier l'orthographe des noms de rondes}
menuText F ToolsMaintFixBase "Rparer base" 0 {Essaie de rparer une base corrompue}
menuText F ToolsConnectHardware "Brancher hardware" 0 {Brancher hardware extrieur}
menuText F ToolsConnectHardwareConfigure "Configurer..." 0 {Configurer la connexion au hardware extrieur}
menuText F ToolsConnectHardwareNovagCitrineConnect "Brancher Novag Citrine" 0 {Brancher Novag Citrine}
menuText F ToolsConnectHardwareInputEngineConnect "Brancher priphrique d'entre" 0 {Brancher riphrique d'entre (par ex. DGT)}
menuText F ToolsPInfo "Information sur les joueurs"  0 \
  {Ouvrir/Mettre  jour la fentre d'information sur les joueurs}
menuText F ToolsPlayerReport "Rapport pour le joueur" 3 \
  {Gnrer un rapport pour le joueur}
menuText F ToolsRating "Elo graphique" 0 \
  {Tracer un graphique du classement Elo des joueurs de cette partie}
menuText F ToolsScore "Score graphique" 0 {Montrer le graphique des scores}
menuText F ToolsExpCurrent "crire la partie en cours" 22 \
  {crire la partie en cours dans un fichier texte}
menuText F ToolsExpCurrentPGN "Dans un fichier PGN..." 16 \
  {crire la partie en cours dans un fichier PGN}
menuText F ToolsExpCurrentHTML "Dans un fichier HTML..." 16 \
  {crire la partie en cours dans un fichier HTML}
menuText F ToolsExpCurrentHTMLJS "Dans un fichier HTML et JavaScript..." 16 {crire la partie en cours dans un fichier HTML et JavaScript}  
menuText F ToolsExpCurrentLaTeX "Dans un fichier LaTeX..." 16 \
  {crire la partie en cours dans un fichier LaTeX}
menuText F ToolsExpFilter "crire le filtre " 2 \
  {crire le filtre dans un fichier texte}
menuText F ToolsExpFilterPGN "Dans un fichier PGN..." 16 \
  {crire le filtre dans un fichier PGN}
menuText F ToolsExpFilterHTML "Dans un fichier HTML..." 16 \
  {crire le filtre dans un fichier HTML}
menuText F ToolsExpFilterHTMLJS "Dans un fichier HTML et JavaScript..." 16 {crire le filtre dans un fichier HTML et JavaScript}  
menuText F ToolsExpFilterLaTeX "Dans un fichier LaTeX..." 16 \
  {crire le filtre dans un fichier LaTeX}
menuText F ToolsExpFilterEPD "Dans un fichier EPD/FEN" 17 {crire le filtre dans un fichier EPD/FEN}
menuText F ToolsExpFilterGames "Exporter une liste de parties vers un fichier texte" 19 {crire une liste de parties vers un fichier texte format}
menuText F ToolsImportOne "Importer une partie en PGN..." 0 \
  {Importer une partie  partir d'un texte PGN}
menuText F ToolsImportFile "Importer un fichier en PGN..." 12 \
  {Importer des parties  partir d'un fichier PGN}
menuText F ToolsStartEngine1 "Dmarrer moteur 1" 0  {Dmarrer moteur 1}
menuText F ToolsStartEngine2 "Dmarrer moteur 2" 0  {Dmarrer moteur 2}
menuText F ToolsScreenshot "Capture conseil" 0
menuText F Play "Jouer" 0
menuText F CorrespondenceChess "Echecs par correspondance" 0 {eMail et Xfcc checs par correspondance}
menuText F CCConfigure "Configurer..." 0 {Configurer outils externes et config gnrale}
menuText F CCConfigRelay "Configurer observations..." 10 {Configurer quelles parties pour les observer}
menuText F CCOpenDB "Ouvrir base..." 0 {Ouvrir la base de jeu par correspondance par dfaut}
menuText F CCRetrieve "Rcuprer parties" 0 {Rcuprer les parties via Xfcc}
menuText F CCInbox "Analyser bote" 0 {Analyser tous les fichiers dans la bote de rception de Scid}
menuText F CCSend "Envoyer coup" 0 {Envoyer votre coup via eMail ou outil externe (Xfcc)}
menuText F CCResign "Abandonner" 0 {Abandonner (pas par eMail)}
menuText F CCClaimDraw "Rclamer la nulle" 0 {Envoyer coup et rclamer nulle (pas par eMail)}
menuText F CCOfferDraw "Proposer la nulle" 0 {Envoyer coup et proposer nulle (pas par eMail)}
menuText F CCAcceptDraw "Accepter la nulle" 0 {Accepter la nulle (pas par eMail)}
menuText F CCNewMailGame "Nouvelle partie eMail..." 0 {Commencer une nouvelle partie par eMail}
menuText F CCMailMove "eMailer le coup..." 0 {Envoyer le coup par eMail  l'adversaire}
menuText F CCGamePage "Page partie..." 0 {Ouvrir la partie dans navigateur web}
menuText F CCEditCopy "Copier parties dans Clipbase" 0 {Copy the games as CSV list to clipbase}


# Options menu:
menuText F Options "Options" 0
menuText F OptionsBoard "Echiquier" 0 {Options d'aspect de l'chiquier}
menuText F OptionsColour "Couleurs" 0 {Default text widget color}
menuText F OptionsBackColour "Arrire-plan" 0 {Default text widget color}
menuText F OptionsBackColourGlobal "Couleur de fond" 0 {Global background color}
menuText F OptionsMainLineColour "Flche coup principal" 0 {Mainline arrows}
menuText F OptionsVarLineColour "Flche coup variante" 0 {Variation arrows}
menuText F OptionsEngineLineColour "Flche moteur" 0 {Flche moteur}
menuText F OptionsRowColour "Surlignage coup bibliothque" 0 {Default tree/book row color}
menuText F OptionsHighlightColour "Surbrillance" 0 {Default text highlight color}
menuText F OptionsSwitcherColour "Surlignage db switcher" 0 {Default db switcher color}
menuText F OptionsProgressColour "Barre de progression" 0 {Default progressbar color}
menuText F OptionsScoreColour "Barres graphiques de score" 0 {}
menuText F OptionsScoreBarColour "Barre du score courant" 0 {}
menuText F OptionsNames "Mes noms de joueurs..." 0 {Editer mes noms de joueurs}
menuText F OptionsExport "Exportation" 0 {Changer les options d'exportation}
menuText F OptionsFonts "Polices" 0 {Changer les polices}
menuText F OptionsFontsRegular "Normales" 0 {Changer les polices normales}
menuText F OptionsFontsMenu "Menu" 0 {Changer la police des menus}
menuText F OptionsFontsSmall "Petites" 0 {Changer les petites polices}
menuText F OptionsFontsFixed "Fixe" 0 {Changer les polices de chasse fixe}
menuText F OptionsEvalbar "Options de la barre de score" 0 {Score bar options}
menuText F OptionsGInfo "Informations de la partie" 7 {Options d'information de la partie}
menuText F OptionsFics "FICS" 0
menuText F OptionsFicsAuto "Autopromote Reine" 0
menuText F OptionsFicsClk "Sauver la pendule" 0
menuText F OptionsFicsColour "Couleur du texte" 0
menuText F OptionsFicsSize "Taille de l'chiquier" 0
menuText F OptionsFicsButtons "Boutons paramtrables" 0
menuText F OptionsFicsCommands "Script d'initialisation" 0
menuText F OptionsFicsNoRes "Sans rsultats" 0
menuText F OptionsFicsNoReq "Sans requtes" 0
menuText F OptionsFicsPremove "Pr-move accept" 0
menuText F OptionsEvalMain "Echiquier principale" 0
menuText F OptionsEvalBrowser "Explorateur de parties" 0
menuText F OptionsEvalFics "Echiquier FICS" 0
menuText F OptionsEvalTime "Temps d'valuation" 0 {Time for quick analysis probe}
# ====== TODO To be translated ======
menuText F OptionsEvalScale "Scale" 0 {Scorebar scale}
# ====== TODO To be translated ======
menuText F OptionsEvalTicks "Show ticks" 0
menuText F OptionsEvalLog  "Evaluation logarithmique" 0
menuText F OptionsLanguage "Langues" 0 {Slectionner le menu de choix des langues}
menuText F OptionsMovesTranslatePieces "Traduction des pices" 0 {Convertit la premire lettre des pices}
menuText F OptionsMovesHighlightLastMove "Surbrillance dernier coup" 0 {Surbrillance du dernier coup}
menuText F OptionsMovesHighlightLastMoveDisplay "Afficher" 0 {Afficher la surbrillance du dernier coup}
menuText F OptionsMovesHighlightLastMoveWidth "Epaisseur" 0 {Epaisseur de la ligne}
menuText F OptionsMovesHighlightLastMoveColor "Couleur" 0 {Couleur de la ligne}
menuText F OptionsMovesColorSelected "Couleur slectionne Carr" 0 {Color move}
menuText F OptionsMoves "Coups" 2 {Gestion des coups}
menuText F OptionsMovesAsk "Demander avant d'craser les coups" 0 \
  {Demander avant d'craser un coup existant}
menuText F OptionsMovesAnimate "Temps d'animation" 1 \
  {Fixe le temps utilis pour l'animation des coups}
menuText F OptionsMovesDelay "Dlai entre les coups" 3 \
  {Positionner le dlai entre deux coups en mode automatique}
menuText F OptionsMovesCoord "Coordonnes entre les coups" 0 \
  {Accepter l'entre des coups par coordonnes ("g1f3")}
menuText F OptionsMovesSuggest "Montrer les coup suggrs" 0 {Turn on/off move suggestion}
menuText F OptionsShowVarPopup "Montrer fentre des variantes" 0 {Affichage automatique des variantes}  
menuText F OptionsMovesSpace "Ajouter un espace aprs le numro du coup" 0 {Espace aprs numro du coup}  
menuText F OptionsMovesKey "Compltion clavier" 0 \
  {Activer/Dsactiver le mode de compltion du clavier}
menuText F OptionsMovesShowVarArrows "Montrer flches pour les variations" 0 {Montrer des flches pour les variations existantes}
menuText F OptionsNumbers "Format numrique" 7 {Slectionner le format des nombres}
menuText F OptionsStartup "Dmarrage" 3 {Slectionner les fentres  ouvrir au dmarrage}
menuText F OptionsTheme "Apparence" 0 {Change l'apparence de l'interface}
menuText F OptionsWindows "Fentres" 0 {Options des fentres}
menuText F OptionsWindowsIconify "Mise en icone automatique" 5 \
  {Mettre toutes les fentres en icones quand la fentre principale est mise en icone}
menuText F OptionsWindowsRaise "Apparition automatique" 0 \
  {Faire apparatre certaines fentres (i.e. barres de progression)  chaque fois qu'elles sont obscurcies}
menuText F OptionsSounds "Sons..." 2 {Configurer l'annonce des sonore des coups}
menuText F OptionsWindowsDock "Fentres groupes" 0 {Fentres groupes (ncessite un redmarrage)}
menuText F OptionsWindowsSaveLayout "Enregistrer disposition" 0 {Enregistrer disposition}
menuText F OptionsWindowsRestoreLayout "Remettre disposition" 0 {Remettre disposition}
menuText F OptionsWindowsShowGameInfo "Montrer le panneau d'info" 0 {Montrer le panneau d'info}
menuText F OptionsWindowsAutoLoadLayout "Chargement auto 1re disposition" 0 {Chargement auto de la premire disposition au dmarrage}
menuText F OptionsWindowsAutoResize "Redimensionnement automatique" 0 {}
menuText F OptionsWindowsFullScreen "Plein cran" 0 {Basculer en mode plein cran}
menuText F OptionsToolbar "Barre d'outils de la fentre principale" 12 \
  {Montrer/Cacher dans la barre d'outils de la fentre principale}
menuText F OptionsECO "Charger le fichier ECO..." 20 \
  {Charger un fichier au format ECO}
menuText F OptionsSpell "Charger le fichier d'orthographe..." 25 \
  {Charger un fichier de correction orthographique scid}
menuText F OptionsTable "Rpertoire des tables de finales TB..." 0 \
  {Slectionner un rpertoire de fichiers TB, tous les fichiers de ce rpertoire seront utiliss}
menuText F OptionsRecent "Fichiers rcents..." 0 \
  {Changer le nombre de fichiers rcents affichs dans le menu Fichier}
menuText F OptionsBooksDir "Rpertoire des bibliothques..." 0 {Rpertoire des bibliothques d'ouverture}
menuText F OptionsTacticsBasesDir "Rpertoire des bases d'entrainement..." 0 {Rpertoire des bases pour l'entrainement tactique}
menuText F OptionsInformant "Configurer les valeurs de notation" 0
menuText F OptionsSave "Sauver les options" 0 "Sauver les options dans le fichier $::optionsFile"
menuText F OptionsSaveBases "Mmorisation des bases ouvertes" 0 
menuText F OptionsAutoSave "Sauvegarde automatique des options" 0 \
  {Sauvegarder automatiquement toutes les options en quittant Scid}

# Help menu:
menuText F Help "Aide" 0
menuText F HelpContents "Contenu" 0 {Montrer la page du contenu de l'aide}
menuText F HelpIndex "Index" 0 {Afficher la table des matires}
menuText F HelpGuide "Aide Rapide" 5 {Montrer la page d'aide rapide}
menuText F HelpHints "Astuces" 0 {Afficher les trucs et astuces}
menuText F HelpContact "Contact" 0 {Afficher les noms des contacts}
menuText F HelpTip "Astuce du jour" 0 {Afficher une astuce Scid}
menuText F HelpStartup "Fentre de dmarrage" 0 {Afficher la fentre de dmarrage}
menuText F HelpAbout "A propos de Scid" 2 {Information au sujet de Scid}

# Game info box popup menu:
menuText F GInfoHideNext "Cacher le coup suivant" 0
menuText F GInfoShow "Le joueur au trait" 0
menuText F GInfoCoords "Coordonnes" 0
menuText F GInfoMaterial "Montrer les valeurs de matriel" 0
menuText F GInfoFEN "Montrer la notation FEN" 5
menuText F GInfoMarks "Montrer les cases colores et les flches" 5
menuText F GInfoWrap "Dcouper les longues lignes" 0
menuText F GInfoFullComment "Montrer tous les commentaires" 10
menuText F GInfoPhotos "Montrer les Photos" 5
menuText F GInfoTBNothing "Tables de finales: Rien" 12
menuText F GInfoTBResult "Tables de finales: Seulement le rsultat" 12
menuText F GInfoTBAll "Tables de finales: rsultat et meilleurs coups" 19
menuText F GInfoDelete "(Rcuprer)Effacer cette partie" 4
menuText F GInfoMark "(D)Marquer cette partie" 4
menuText F GInfoMenuBar "Barre de Menu"  0
menuText F GInfoToolBar "Barre d'outils"  0
menuText F GInfoButtonBar "Barre  boutons"  0
menuText F GInfoStatusBar "Barre d'tat"  0
menuText F GInfoEvalBar "Barre d'valuation" 0
translate F FlipBoard {Retourner l'chiquier}
translate F RaiseWindows {Fentre d'arbitrage}
translate F AutoPlay {Lecture automatique}
translate F TrialMode {Mode d'essai}
translate F KeepOpen {Afficher au dmarrage}

# General buttons:
translate F Apply {Appliquer}
translate F Back {Retour}
translate F Browse {Parcourir}
translate F Cancel {Annuler}
translate F Continue {Continuer}
translate F Clear {Effacer}
translate F Close {Fermer}
translate F Contents {Contenu}
translate F Defaults {Par dfaut}
translate F Delete {liminer}
translate F Graph {Graphique}
translate F Help {Aide}
translate F Import {Importer}
translate F Index {Index}
translate F LoadGame {Charger partie}
translate F BrowseGame {Explorer la partie dans une fentre spare}
translate F MergeGame {Fusionner la partie comme variante}
translate F MergeGames {Fusionner les parties}
translate F Preview {Prvisualiser}
translate F Revert {Revenir}
translate F Save {Enregistrer}
translate F DontSave {Ne pas sauver}
translate F Search {Rechercher}
translate F Stop {Arrter}
translate F Store {Enregistrer}
translate F Update {Mettre  jour}
translate F ChangeOrient {Changer l'orientation de la fentre}
translate F ShowIcons {Montrer les icones}
translate F ConfirmCopy {Confirmer la copie}
translate F None {Aucun}
translate F First {Premier}
translate F Current {En cours}
translate F Last {Dernier}
translate F Font {Police}
translate F Change {Changer}
translate F Random {Alatoire}

# General messages:
translate F game {partie}
translate F games {parties}
translate F move {coup}
translate F moves {coups}
translate F all {tout}
translate F Yes {Oui}
translate F No {Non}
translate F Both {Les deux}
translate F King {Roi}
translate F Queen {Dame}
translate F Rook {Tour}
translate F Bishop {Fou}
translate F Knight {Cavalier}
translate F Pawn {Pion}
translate F White {Blancs}
translate F Black {Noirs}
translate F Player {Joueur}
translate F Rating {Classement ELO}
translate F RatingDiff {Diffrence de classement ELO (Blancs - Noirs)}
translate F AverageRating {Classement moyen}
translate F Event {vnement}
translate F Site {Lieux}
translate F Country {Pays}
translate F IgnoreColors {Ignorer les couleurs}
translate F MatchEnd {Positon finale uniquement}
translate F Date {Date}
translate F EventDate {vnement date}
translate F Decade {Dcennie}
translate F Year {Anne}
translate F Month {Mois}
translate F Months {Janvier Fvrier Mars Avril Mai Juin Juillet Aot Septembre Octobre Novembre Dcembre}
translate F Days {Dim Lun Mar Mer Jeu Ven Sam}
translate F YearToToday {Anne jusqu' aujourd'hui}
translate F Result {Rsultat}
translate F Round {Ronde}
translate F Length {Longueur}
translate F ECOCode {code ECO}
translate F ECO {ECO}
translate F Deleted {limin}
translate F SearchResults {Rsultats de la recherche}
translate F OpeningTheDatabase {Ouverture de la base}
translate F Database {Base}
translate F Filter {Filtre}
translate F Reset {Rinitialiser}
translate F IgnoreCase {Ignorer la Casse}
translate F noGames {pas de parties}
translate F allGames {toutes les parties}
translate F empty {vide}
translate F clipbase {presse-papier}
translate F score {score}
translate F Start {Position}
translate F StartPos {Position de dpart}
translate F Total {Total}
translate F readonly {lecture seule}
translate F altered {chang}
translate F tagsDescript {Extra tags (ex: Annotator "Anand")}
translate F prevTags {Prcdent}
translate F value {Valeur}

# Standard error messages:
translate F ErrNotOpen {Ceci n'est pas une base ouverte.}
translate F ErrReadOnly {Cette base est en lecture seule; elle ne peut tre modifie.}
translate F ErrSearchInterrupted {La recherche a t interrompue; les rsultats sont incomplets.}

# Game information:
translate F twin {doublon}
translate F deleted {limin}
translate F comment {commentaire}
translate F hidden {cach}
translate F LastMove {Dernier coup}
translate F NextMove {Coup suivant}
translate F GameStart {Dbut de partie}
translate F LineStart {Dbut de ligne}
translate F GameEnd {Fin de partie}
translate F LineEnd {Fin de ligne}

# Player information:
translate F PInfoAll {toutes les parties}
translate F PInfoFilter {les parties filtres}
translate F PInfoAgainst {Rsultats contre}
translate F PInfoMostWhite {Ouvertures les plus frquentes avec les blancs}
translate F PInfoMostBlack {Ouvertures les plus frquentes avec les noirs}
translate F PInfoRating {Historique du classement}
translate F PInfoBio {Biographie}
translate F PInfoEditRatings {Editer les Classements}
translate F PinfoEditName {Editer nom}
translate F PinfoLookupName {Chercher nom}

# Tablebase information:
translate F Draw {Nulle}
translate F stalemate {pat}
translate F checkmate {mat}
translate F withAllMoves {avec tous les coups}
translate F withAllButOneMove {avec tous les coups sauf le dernier}
translate F with {avec}
translate F only {seulement}
translate F lose {perte}
translate F loses {pertes}
translate F allOthersLose {toutes les autres pertes}
translate F matesIn {mat en}
translate F longest {le plus long}
translate F WinningMoves {Coups gagnants}
translate F DrawingMoves {Coups faisant nulle}
translate F LosingMoves {Coups perdants}
translate F UnknownMoves {Coups dont le rsultat est inconnu}

# Tip of the day:
translate F Tip {Conseil}
translate F TipAtStartup {Conseil au dmarrage}

# Tree window menus:
menuText F TreeFile "Fichier" 0
menuText F TreeFileFillWithBase "Remplir cache avec base" 0 {Remplir le cache avec toutes les parties de la base courante}
menuText F TreeFileFillWithGame "Remplir cache avec partie" 0 {Remplir le cache avec la partie de la base courante}
menuText F TreeFileCacheInfo "Info cache" 0 {Afficher information sur l'utilisation du cache}
menuText F TreeFileSave "Sauver le cache" 0
menuText F TreeFileFill "Remplir le cache" 0
menuText F TreeFileBest "Liste des meilleures parties" 0 {Montrer la liste des meilleures parties}
menuText F TreeFileGraph "Graphique" 0 {Graphique de l'arbre}
menuText F TreeFileCopy "Copier l'arbre dans le presse-papiers" 0
menuText F TreeFileClose "Fermer la fentre d'arbre" 0
menuText F TreeMask "Masque" 0
menuText F TreeMaskNew "Nouveau" 0 {Nouveau masque}
menuText F TreeMaskOpen "Ouvrir" 0 {Ouvrir masque}
menuText F TreeMaskOpenRecent "Ouvrir rcent" 0 {Ouvrir un masque rcent}
menuText F TreeMaskSave "Sauver" 0 {Sauver masque}
menuText F TreeMaskClose "Fermer" 0 {Fermer masque}
menuText F TreeMaskFillWithLine "Remplir avec ligne" 0 {Remplir le masque avec toutes les coups prcdents}
menuText F TreeMaskFillWithGame "Remplir avec partie" 0 {Remplir le masque avec partie}
menuText F TreeMaskFillWithBase "Remplir avec base" 0 {Remplir le masque avec les parties de la base}
menuText F TreeMaskInfo "Info" 0 {Statistiques du masque}
menuText F TreeMaskDisplay "Afficher l'arbre" 0 {Affichage des donnes du masque sous la forme d'un arbre}
menuText F TreeMaskSearch "Chercher" 0 {Chercher dans le masque courant}
menuText F TreeSort "Trier" 0
menuText F TreeSortAlpha "Alphabtique" 0
menuText F TreeSortECO "code ECO" 0
menuText F TreeSortFreq "Frquence" 0
menuText F TreeSortScore "Score" 0
menuText F TreeOpt "Options" 0
menuText F TreeOptSlowmode "Mode lent" 0 {Mode lent pour rafraichissement (prcis)}
menuText F TreeOptFastmode "Mode rapide" 0 {Mode rapide pour rafraichissement (pas de transpositions)}
menuText F TreeOptFastAndSlowmode "Mode rapide puis lent" 0 {Mode rapide puis lent pour rafraichissement}
menuText F TreeOptStartStop "Rafrachissement auto" 0 {Rafrachissement automatique de la fentre}
menuText F TreeOptLock "Verrouille" 0 {D/verrouiller l'arbre  la base en cours}
menuText F TreeOptTraining "Entranement" 0 {Dmarrer/Arrter l'arbre du mode d'entranement}
menuText F TreeOptShort "Affichage court" 0 {Affichage sans donnes ELO}
menuText F TreeOptAutosave "Sauver le cache automatiquement" 0
menuText F TreeOptAutomask "Auto-chargement Mask" 0 "Auto-Load most recent mask with a tree open."
menuText F TreeOptCacheSize "Taille du cache" 0 {Taille du cache}
menuText F TreeOptShowBar "Affichage barre de progression" 0 "Show tree progress bar."
menuText F TreeOptShowFrame "Affichage fentre boutons" 0 "Afficher la fentre de boutons."
menuText F TreeOptSmallFont "Utiliser polices personalises" 0 "Utiliser petite police pour liste des parties"
menuText F TreeOptSortBest "Tri des meilleurs jeux" 0 "Tri des meilleurs jeux selon ELO."
menuText F TreeHelp "Aide" 0
menuText F TreeHelpTree "Aide Arbre" 0
menuText F TreeHelpIndex "Index" 0


translate F SaveCache {Sauver le cache}
translate F Training {Entranement}
translate F LockTree {Verrouiller}
translate F TreeLocked {verrouill}
translate F TreeBest {Meilleur}
translate F TreeBestGames {Arbre des meilleures parties}
translate F TreeAdjust {Ajuster filtre}
# Note: the next message is the tree window title row. After editing it,
# check the tree window to make sure it lines up with the actual columns.
translate F TreeTitleRow      {    Coup       Frquence   Score Nulle EloMoy Perf Anne ECO}
translate F TreeTitleRowShort {    Coup       Frquence   Score Nulle}
translate F TreeTotal: {TOTAL:}
translate F DoYouWantToSaveFirst {voulez-vous d'abord sauvegarder}
translate F AddToMask {Ajouter au masque}
translate F RemoveFromMask {Enlever du masque}
translate F AddThisMoveToMask {Ajouter ce coup au masque}
translate F SearchMask {Recherche dans masque}
translate F DisplayMask {Affichage du masque}
translate F MaskShowMarkers "Montrer les marqueurs"
translate F MaskShowToolTips {Montrer les info-bulles}
translate F Nag {Code Nag}
translate F Marker {Marqueur}
translate F Include {Inclure}
translate F Exclude {Exclure}
translate F MainLine {Ligne principale}
translate F Bookmark {Signet}
translate F NewLine {Nouvelle ligne}
translate F ToBeVerified {A vrifier}
translate F ToTrain {S'entrainer}
translate F Dubious {Douteux}
translate F ToRemove {A supprimer}
translate F NoMarker {Aucun marqueur}
translate F ColorMarker {Couleur}
translate F WhiteMark {Blanc}
translate F GreenMark {Vert}
translate F YellowMark {Jaune}
translate F BlueMark {Bleu}
translate F RedMark {Rouge}
translate F CommentMove {Annoter coup}
translate F CommentPosition {Annoter position}
translate F AddMoveToMaskFirst {Ajoutez d'abord le coup au masque}
translate F OpenAMaskFileFirst {Ouvrez d'abord un masque}
translate F positions {Positions}
translate F Moves {Coups}

# Finder window:
menuText F FinderFile "Fichier" 0
menuText F FinderFileSubdirs "Rechercher dans les sous rpertoires" 0
menuText F FinderFileClose "Fermer l'explorateur de fichiers" 0
menuText F FinderSort "Trier" 0
menuText F FinderSortType "Type" 0
menuText F FinderSortSize "Taille" 0
menuText F FinderSortMod "Modifi" 0
menuText F FinderSortName "Nom" 0
menuText F FinderSortPath "Chemin" 0
menuText F FinderTypes "Types" 0
menuText F FinderTypesScid "Bases Scid" 0
menuText F FinderTypesOld "Bases Scid  l'ancien format" 0
menuText F FinderTypesPGN "fichiers PGN" 0
menuText F FinderTypesEPD "fichiers EPD (thorie)" 0
menuText F FinderHelp "Aide" 0
menuText F FinderHelpFinder "Aide de l'explorateur de fichiers" 0
menuText F FinderHelpIndex "Index" 0
translate F FileFinder {Explorateur de fichiers}
translate F FinderDir {Rpertoire}
translate F FinderDirs {Rpertoires}
translate F FinderFiles {Fichiers}
translate F FinderUpDir {rpertoire prcdent}
translate F FinderCtxOpen {Ouvrir}
translate F FinderCtxBackup {Sauvegarder}
translate F FinderCtxCopy {Copier}
translate F FinderCtxMove {Dplacer}
translate F FinderCtxDelete {Supprimer}
translate F FinderCtxRename {Renommer}
translate F FinderDirOpen {Ouvrir Rpertoire}

# Player finder:
menuText F PListFile "Fichier" 0
menuText F PListFileUpdate "Mettre  jour" 0
menuText F PListFileClose "Fermer la recherche de joueur" 0
menuText F PListSort "Trier" 0
menuText F PListSortName "Nom" 0
menuText F PListSortElo "Elo" 0
menuText F PListSortGames "Parties" 0
menuText F PListSortOldest "Les plus vieux" 0
menuText F PListSortNewest "Les plus rcents" 0
menuText F PListSortCountry "Pays" 0

# Tournament finder:
menuText F TmtFile "Fichier" 0
menuText F TmtFileUpdate "Mettre  jour" 0
menuText F TmtFileClose "Fermer l'explorateur de tournois" 0
menuText F TmtSort "Trier" 0
menuText F TmtSortDate "Date" 0
menuText F TmtSortPlayers "Joueurs" 0
menuText F TmtSortGames "Parties" 0
menuText F TmtSortElo "Elo" 0
menuText F TmtSortSite "Lieux" 0
menuText F TmtSortEvent "vnement" 1
menuText F TmtSortWinner "Vainqueur" 0
translate F TmtLimit "Limite de liste"
translate F TmtMeanElo "Moyenne ELO la plus basse"
translate F TmtNone "Aucun tournoi correspondant n'a t trouv."

# Graph windows:
menuText F GraphFile "Fichier" 0
menuText F GraphFileColor "Sauver comme Postscript en couleurs..." 27
menuText F GraphFileGrey "Sauver comme Postscript en niveaux de gris..." 27
menuText F GraphFileClose "Fermer la fentre" 0
menuText F GraphOptions "Options" 0
menuText F GraphOptionsWhite "Blancs" 0
menuText F GraphOptionsBlack "Noirs" 0
menuText F GraphOptionsDots "Montrer les points connus" 0
menuText F GraphOptionsSpelling "Elo from Spelling File" 0
menuText F GraphOptionsBar "Surbrillance de la position actuelle" 0
menuText F GraphOptionsBoth "Les deux" 4
menuText F GraphOptionsPInfo "Informations joueurs" 0
translate F GraphFilterTitle "Graphique de filtre: frquence pour 1000 parties"
translate F GraphAbsFilterTitle "Graphique de filtre: frquence des parties"
translate F ConfigureFilter {Configurer l'axe des X par anne, classement et coups}
translate F FilterEstimate "Estimer"
translate F TitleFilterGraph "Scid: Graphe de filtre"

# Analysis window:
translate F AddVariation {Ajouter une variante}
translate F AddAllVariations {Ajouter toutes les variantes}
translate F AddMove {Ajouter le coup}
translate F Annotate {Annotation}
translate F ShowAnalysisBoard {Montrer chiquier d'analyse}
translate F ShowInfo {Montrer infos moteur}
translate F FinishGame {Continuer la partie}
translate F StopEngine {Arrter le moteur}
translate F StartEngine {Dmarrer le moteur}
translate F ExcludeMove {Exclure coup}
translate F LockEngine {Verrouiller moteur  la position actuelle}
translate F AnalysisCommand {Commande d'analyse}
translate F PreviousChoices {Choix prcdents}
translate F AnnotateTime {Fixer le temps en secondes entre deux coups}
translate F AnnotateWhich {Ajouter des variantes}
translate F AnnotateAll {Pour les coups des deux cots}
translate F AnnotateAllMoves {Annoter tous les coups}
translate F AnnotateWhite {Pour les coups des blancs seulement}
translate F AnnotateBlack {Pour les coups des noirs seulement}
translate F AnnotateNotBest {Quand le coup de la partie n'est pas le meilleur}
translate F AnnotateBlundersOnly {Quand le coup est une erreur}
translate F BlundersNotBest {Erreurs/Imprcissions}
translate F AnnotateTitle {Configurer Annotation}
translate F AnnotateMissedMates {Occasion manque/Mat en moins de coups}
translate F AnnotateEnd { la fin du jeu}
translate F BlundersThreshold {Seuil de l'erreur}
translate F ScoreFormat {Format du score}
translate F CutOff {Interruption}
translate F LowPriority {Priorit processeur basse}
translate F LogEngines {Taille du journal}
translate F LogName {Ajouter nom}
translate F MaxPly {Demi-coups fixes}
translate F ClickHereToSeeMoves {Cliquer ici pour afficher les coups}
translate F ConfigureInformant {Configurer les valeurs des notations}
translate F Informant!? {Coup intressant}
translate F Informant? {Coup faible}
translate F Informant?? {Mauvais coup}
translate F Informant?! {Coup douteux}
translate F Informant+= {Les blancs ont un lger avantage}
translate F Informant+/- {Les blancs ont l'avantage}
translate F Informant+- {Les blancs ont un avantage dcisif}
translate F Informant++- {La partie est gagne}

# Book window
translate F Book {Bibliothque}
translate F OtherBook {Autres mouvements}
translate F Alphabetical {Alphabtique}
translate F TwoBooks {Deux livres}

# Analysis Engine open dialog:
translate F EngineList {Liste des moteurs d'analyse}
translate F EngineKey {Touche}
translate F EngineType {Protocole}
translate F EngineName {Nom}
translate F EngineCmd {Commande}
translate F EngineArgs {Paramtres}
translate F EngineDir {Rpertoire}
translate F EngineElo {Elo}
translate F EngineTime {Date}
translate F EngineNew {Nouvelle}
translate F EngineEdit {diter}
translate F EngineRequired {Les champs en gras sont requis; les autres sont optionnels}

# Stats window menus:
menuText F StatsFile "Fichier" 0
menuText F StatsFilePrint "crire dans fichier..." 0
menuText F StatsFileClose "Fermer la fentre" 0
menuText F StatsOpt "Options" 0

# PGN window menus:
menuText F PgnFile "Fichier" 0
menuText F PgnFileCopy "Copier la partie dans le Presse-papier" 0
menuText F PgnFilePrint "crire dans fichier..." 0
menuText F PgnFileClose "Fermer la fentre PGN" 0
menuText F PgnOpt "Affichage" 0
menuText F PgnOptColor "Couleur d'affichage" 0
menuText F PgnOptShort "Entte court (3-lignes)" 0
menuText F PgnOptSymbols "Annotations symboliques" 0
menuText F PgnOptIndentC "Indentation des commentaires" 0
menuText F PgnOptIndentV "Indentation des variantes" 16
menuText F PgnOptColumn "Style en colonne (un coup par ligne)" 1
menuText F PgnOptSpace "Espace aprs numro des coups" 0
menuText F PgnOptStripMarks "Enlever les codes de flches et de coloration de cases" 1
menuText F PgnOptChess "Echecs Pices" 0
menuText F PgnOptScrollbar "Barre de dfilement" 0
menuText F PgnOptBoldMainLine "Mettre en gras les coups de la ligne principale" 4
menuText F PgnColor "Couleur" 0
menuText F PgnColorHeader "Entte..." 0
menuText F PgnColorAnno "Annotations..." 0
menuText F PgnColorComments "Commentaires..." 0
menuText F PgnColorVars "Variantes..." 0
menuText F PgnColorBackground "Couleur du fond..." 11
menuText F PgnColorMain "Ligne principale..." 0
menuText F PgnColorCurrent "Surbrillance du coup jou..." 1
menuText F PgnColorNextMove "Surbrillance du coup suivant..." 0
menuText F PgnHelp "Aide" 0
menuText F PgnHelpPgn "Aide PGN" 0
menuText F PgnHelpIndex "Index" 0
translate F PgnWindowTitle {Notation partie - partie %u}

# Crosstable window menus:
menuText F CrosstabFile "Fichier" 0
menuText F CrosstabFileText "crire dans un fichier texte..." 23
menuText F CrosstabFileHtml "crire dans un fichier HTML..." 23
menuText F CrosstabFileLaTeX "crire dans un fichier LaTeX..." 23
menuText F CrosstabFileClose "Fermer fentre tableau" 0
menuText F CrosstabEdit "diter" 0
menuText F CrosstabEditEvent "vnement" 0
menuText F CrosstabEditSite "Lieux" 0
menuText F CrosstabEditDate "Date" 0
menuText F CrosstabOpt "Affichage" 0
menuText F CrosstabOptColorPlain "Texte normal" 0
menuText F CrosstabOptColorHyper "Hypertexte" 0
menuText F CrosstabOptTieWin "Dpartage par nombre de victoires" 1
menuText F CrosstabOptTieHead "Dpartage par confrontation directe" 1
menuText F CrosstabOptThreeWin "3 Points pour une victoire" 1
menuText F CrosstabOptAges "Ages en annes" 8
menuText F CrosstabOptNats "Nationalits" 0
menuText F CrosstabOptTallies "Victoires/Dfaites/Nulles" 0
menuText F CrosstabOptRatings "Classements" 0
menuText F CrosstabOptTitles "Titres" 0
menuText F CrosstabOptBreaks "Scores du dpartage" 4
menuText F CrosstabOptDeleted "Inclure les parties effaces" 8
menuText F CrosstabOptColors "Couleurs (systme suisse uniquement)" 1
menuText F CrosstabOptColorRows "Lignes colores" 0
menuText F CrosstabOptRowsColor "Couleur de la ligne" 0 {Default crosstable row color}
menuText F CrosstabOptColumnNumbers "Colonnes numrotes (Toutes rondes seulement)" 2
menuText F CrosstabOptGroup "Scores du groupe" 0
menuText F CrosstabSort "Trier" 0
menuText F CrosstabSortName "Nom" 0
menuText F CrosstabSortRating "Elo" 0
menuText F CrosstabSortScore "Score" 0
menuText F CrosstabSortCountry "Pays" 0
menuText F CrosstabType "Systme" 0
menuText F CrosstabTypeAll "Toutes rondes" 0
menuText F CrosstabTypeSwiss "Suisse" 0
menuText F CrosstabTypeKnockout "KO" 0
menuText F CrosstabTypeAuto "Auto" 0
menuText F CrosstabHelp "Aide" 0
menuText F CrosstabHelpCross "Aide tableau" 0
menuText F CrosstabHelpIndex "Index" 0
translate F SetFilter {Activer le filtre}
translate F AddToFilter {Ajouter au filtre}
translate F Swiss {Suisse}
translate F Category {Catgorie}

# Opening report window menus:
menuText F OprepFile "Fichier" 0
menuText F OprepFileText "crire dans un fichier texte..." 23
menuText F OprepFileHtml "crire dans un fichier HTML..." 23
menuText F OprepFileLaTeX "crire dans un fichier LaTeX..." 23
menuText F OprepFileOptions "Options..." 0
menuText F OprepFileClose "Fermer la fentre du rapport" 0
menuText F OprepFavorites "Favoris" 1
menuText F OprepFavoritesAdd "Ajouter au rapport..." 0
menuText F OprepFavoritesEdit "Editer les favoris de rapport..." 0
menuText F OprepFavoritesGenerate "Gnrer les rapports..." 0

menuText F OprepHelp "Aide" 0
menuText F OprepHelpReport "Aide du rapport" 0
menuText F OprepHelpIndex "Index" 0

# Header search:
translate F HeaderSearch {Rechercher Entte}
translate F EndSideToMove {Ct devant jouer  la fin de la partie}
translate F GamesWithNoECO {Partie sans code ECO?}
translate F GameLength {Longueur de la partie}
translate F FindGamesWith {Chercher les parties avec}
translate F StdStart {Pos. dpart non standard}
translate F Promotions {Promotions}
translate F UnderPromo {Promotions mineures}
translate F Comments {Commentaires}
translate F Variations {Variantes}
translate F Annotations {Annotations}
translate F DeleteFlag {Marques supprimes}
translate F WhiteOpFlag {Ouverture des blancs}
translate F BlackOpFlag {Ouverture des noirs}
translate F MiddlegameFlag {Milieu de partie}
translate F EndgameFlag {Finale}
translate F NoveltyFlag {Nouveaut}
translate F PawnFlag {Structure de pions}
translate F TacticsFlag {Tactiques}
translate F QsideFlag {Jeu  l'aile dame}
translate F KsideFlag {Jeu  l'aile roi}
translate F BrilliancyFlag {Spectaculaire}
translate F BlunderFlag {Gaffe}
translate F UserFlag {Utilisateur}
translate F PgnContains {PGN contenant du texte}
translate F PreComment {Commentaires initiaux}
translate F PostComment {Commentaires finaux}

# Game list window:
translate F GlistNumber {Numro}
translate F GlistWhite {Blancs}
translate F GlistBlack {Noirs}
translate F GlistWElo {B-Elo}
translate F GlistBElo {N-Elo}
translate F GlistEvent {vnement}
translate F GlistSite {Lieux}
translate F GlistRound {Ronde}
translate F GlistDate {Date}
translate F GlistYear {Anne}
translate F GlistEventDate {vnement-Date}
translate F GlistResult {Rsultat}
translate F GlistLength {Longueur}
translate F GlistCountry {Pays}
translate F GlistECO {ECO}
translate F GlistOpening {Coups}
translate F GlistEndMaterial {Matriel final}
translate F GlistDeleted {Effac}
translate F GlistFlags {Drapeaux}
translate F GlistVariations {Variantes}
translate F GlistComments {Commentaires}
translate F GlistAnnos {Annotations}
translate F GlistStart {Dpart}
translate F GlistGameNumber {Partie numro}
translate F GlistFindText {Rechercher texte}
translate F GlistMoveField {Coup}
translate F GlistEditField {Configurer}
translate F GlistAddField {Ajouter}
translate F GlistDeleteField {Supprimer}
translate F GlistColor {Couleur}
translate F GlistSort {Trier la base}

# menu shown with right mouse button down on game list.
translate F GlistRemoveThisGameFromFilter  {Enlever}
translate F GlistRemoveGameAndAboveFromFilter  {Enlever cette partie (et celles au-dessus)}
translate F GlistRemoveGameAndBelowFromFilter  {Enlever cette partie (et celles en-dessous)}
translate F GlistDeleteGame {(Ds-)effacer cette partie} 
translate F GlistDeleteAllGames {Effacer toutes les parties du filtre} 
translate F GlistUndeleteAllGames {Ds-effacer toutes les parties du filtre} 
translate F GlistAlignL {Aligner  gauche}
translate F GlistAlignR {Aligner  droite}
translate F GlistAlignC {Centrer}
translate F GlistMoveFieldUp {Monter}
translate F GlistMoveFieldDown {Descendre}
translate F GlistMoveFieldFirst {Passer au premier}
translate F GlistMoveFieldLast {Passer au dernier}
translate F GlistMoveFieldN {Passer au N}

# Maintenance window:
translate F DatabaseName {Nom de base:}
translate F TypeIcon {Type icne}
translate F NumOfGames {Parties:}
translate F NumDeletedGames {Parties supprimes:}
translate F NumFilterGames {Parties dans le filtre:}
translate F YearRange {Annes:}
translate F RatingRange {Classements:}
translate F Description {Description}
translate F Flag {Drapeau}
translate F CustomFlags {Drapeaux personnaliss}
translate F DeleteCurrent {Effacer la partie courante}
translate F DeleteFilter {Effacer le filtre de parties}
translate F DeleteAll {Effacer toutes les parties}
translate F UndeleteCurrent {Rcuprer la partie en cours}
translate F UndeleteFilter {Rcuprer les parties filtres}
translate F UndeleteAll {Rcuprer toutes les parties}
translate F DeleteTwins {Effacer les parties en doublon}
translate F MarkCurrent {Slectionner la partie en cours}
translate F MarkFilter {Slectionner les parties filtres}
translate F MarkAll {Slectionner toutes les parties}
translate F UnmarkCurrent {Dslectionner la partie en cours}
translate F UnmarkFilter {Dslectionner les parties filtres}
translate F UnmarkAll {Dslectionner toutes les parties}
translate F Spellchecking {Vrification orthographique}
translate F MakeCorrections {Faire des corrections}
translate F Ambiguous {Ambigu}
translate F Surnames {Patronymes}
translate F Players {Joueurs}
translate F Events {vnements}
translate F Sites {Lieux}
translate F Rounds {Rondes}
translate F DatabaseOps {Oprations sur la base}
translate F ReclassifyGames {ECO-Classifier les parties...}
translate F CompactDatabase {Compacter la base}
translate F SortDatabase {Trier la base}
translate F AddEloRatings {Ajouter les classements Elo}
translate F AutoloadGame {Chargement automatique du numro de partie}
translate F StripTags {Marqueurs supplmentaires}
translate F StripTag {Enlever les marqueurs}
translate F AddTag {Ajouter un marqueurs}
translate F CheckGames {Vrifier les parties}
translate F Cleaner {Nettoyer}
translate F CleanerHelp {
Le Nettoyeur Scid va raliser pour la base en cours toutes les actions de maintenance que vous avez slectionn  partir de la liste ci-dessous.

Les rglages en cours de la classification ECO et les dialogues d'effacement des jumeaux vont s'appliquer si vous avez slectionn ces fonctions.
}
translate F CleanerConfirm {
Une fois que le nettoyage est commenc, il ne peut tre interrompu!

Cela peut prendre beaucoup de temps sur une grande base, suivant les fonctions que vous avez slectionn et leurs rglages en cours.

Etes vous sr que vous voulez commencer les fonctions de maintenance que vous avez slectionn?
}

translate F TwinCheckUndelete {pour permuter; "u" pour annuler l'effacement des deux}
translate F TwinCheckprevPair {Paire prcdente}
translate F TwinChecknextPair {Paire suivante}
translate F TwinChecker {Scid: vrificateur de doublon}
translate F TwinCheckTournament {Parties dans le tournoi:}
translate F TwinCheckNoTwin {Pas de doublon  }
translate F TwinCheckNoTwinfound {No twin was detected for this game.\nTo show twins using this window, you must first use the "Delete twin games..." function. }
translate F TwinCheckTag {Partager tags...}
translate F TwinCheckFound1 {Scid a trouv $result doublons}
translate F TwinCheckFound2 { et positionn le marquer de suppression}
translate F TwinCheckNoDelete {Il n'y a pas de parties dans cette base  effacer.}
translate F TwinCriteria1 { Les paramtres pour trouver des doublons risquent de\nfaire que des parties diffrentes avec des coups similaires soient marques comme des doublons.}
translate F TwinCriteria2 {Il est recommand de slectionner "Non" pour "mmes coups", vous devriez slectionner "Oui" pour les couleurs, vnement, site, ronde, anne et mois.\nVoulez-vous continuer et effacer les doublons quand mme ? }
translate F TwinCriteria3 {Il est recommand de slectionner "Oui" pour au moins deux des paramtres "mme site", "mme ronde" et "mme anne".\nVoulez-vous continuer et effacer les doublons quand mme ?}
translate F TwinCriteriaConfirm {Scid: Confirmer les paramtres de doublons}
translate F TwinChangeTag "Changer les tags de partie suivants:\n\n"
translate F AllocRatingDescription "Cette commande va utiliser les fichiers de vrification de noms et de classement ELO pour les parties de cette base. Chaque fois qu'un joueur n'a pas de classement mais que son classement est list dans le fichier de vrification de noms  la date de la partie, ce classement est pris en compte."
translate F RatingOverride "Remplacer le classement non nul existant ?"
translate F AddRatings "ajouter classement :"
translate F AddedRatings {Scid a ajout $r classements Elo dans $g parties.}
translate F NewSubmenu "Nouveau sous-menu"

# Comment editor:
translate F AnnotationSymbols {Symboles d'annotation:}
translate F Comment {Commentaire:}
translate F InsertMark {Insre une marque}
translate F InsertMarkHelp {
Insrer/enlever marque: Slectionner la couleur, le type et la case.
Insrer/enlever flche: Clic droit sur deux cases.
}

# Nag buttons in comment editor:
translate F GoodMove {Bon coup}
translate F PoorMove {Coup faible}
translate F ExcellentMove {Excellent coup}
translate F Blunder {Gaffe}
translate F InterestingMove {Coup intressant}
translate F DubiousMove {coup douteux}
translate F WhiteDecisiveAdvantage {Les blancs ont un avantage dcisif}
translate F BlackDecisiveAdvantage {Les noirs ont un avantage dcisif}
translate F WhiteClearAdvantage {Les blancs ont l'avantage}
translate F BlackClearAdvantage {Les noirs ont l'avantage}
translate F WhiteSlightAdvantage {Les blancs ont un lger avantage}
translate F BlackSlightAdvantage {Les noirs ont un lger avantage}
translate F Equality {Egalit}
translate F Unclear {Peu clair}
translate F Diagram {Diagramme}

# Board search:
translate F BoardSearch {Rechercher Position}
translate F FilterOperation {Opration sur le filtre en cours:}
translate F FilterAnd {ET (Restreint le filtre)}
translate F FilterOr {OU (Ajouter au filtre)}
translate F FilterIgnore {IGNORER (Restaure le filtre initial)}
translate F SearchType {Type de recherche:}
translate F SearchBoardExact {Position exacte (mmes pices sur les mmes cases)}
translate F SearchBoardPawns {Pions (mme matriel, tous les pions sur les mmes cases)}
translate F SearchBoardFiles {Colonnes (mme matriel, tous les pions sur mmes colonnes)}
translate F SearchBoardAny {Tous (mme matriel, pions et pices n'importe o)}
translate F SearchInRefDatabase { Dans la base de rfrence }
translate F LookInVars {Chercher dans les variantes}
translate F CQLLabel {Script CQL}
translate F CQLComments {Commentaires accepts}
translate F CQLStrip {Supprimer les commentaires}

# Material search:
translate F MaterialSearch {Rechercher Motifs}
translate F Material {Matriel}
translate F Patterns {Motifs}
translate F Zero {Zro}
translate F Any {Tout}
translate F CurrentBoard {Position en cours}
translate F CommonEndings {Finales}
translate F CommonPatterns {Motifs}
translate F MaterialDiff {Diffrence en matriel}
translate F squares {cases}
translate F SameColor {Mmes couleur}
translate F OppColor {Couleurs opposes}
translate F Either {Les deux}
translate F MoveNumberRange {Dplacer de X coups}
translate F MatchForAtLeast {Correspond  la dernire}
translate F HalfMoves {demi-coups}

# Common endings in material search:
translate F EndingPawns {Finales de pions}
translate F EndingRookVsPawns {Tour contre pion(s)}
translate F EndingRookPawnVsRook {Tour et 1 pion contre Tour}
translate F EndingRookPawnsVsRook {Tour et pion(s) contre Tour}
translate F EndingRooks {Finales Tour contre Tour}
translate F EndingRooksPassedA {Finales de Tour contre Tour avec un pion a pass}
translate F EndingRooksDouble {Finales 2 tours}
translate F EndingBishops {Finales Fou contre Fou}
translate F EndingBishopVsKnight {Finales Fou contre Cavalier}
translate F EndingKnights {Finales Cavalier contre Cavalier}
translate F EndingQueens {Finales Dame contre Dame}
translate F EndingQueenPawnVsQueen {Dame et 1 pion contre Dame}
translate F BishopPairVsKnightPair {Milieu de jeu 2 Fous contre 2 Cavaliers}

# Common patterns in material search:
translate F PatternWhiteIQP {PDI blanc}
translate F PatternWhiteIQPBreakE6 {PDI blanc: la pouse d4-d5 vs e6}
translate F PatternWhiteIQPBreakC6 {PDI blanc: la pouse d4-d5 vs c6}
translate F PatternBlackIQP {PDI noir}
translate F PatternWhiteBlackIQP {PDI blanc vs PDI noir}
translate F PatternCoupleC3D4 {Deux pions isols blancs c3 et d4}
translate F PatternHangingC5D5 {Pions noirs en prise en c5 et d5}
translate F PatternMaroczy {L'tau de Marczy (Pions en c4 et e4)}
translate F PatternRookSacC3 {Le sacrifice de tour en c3}
translate F PatternKc1Kg8 {O-O-O vs O-O (Kc1 vs Kg8)}
translate F PatternKg1Kc8 {O-O vs O-O-O (Kg1 vs Kc8)}
translate F PatternLightFian {Fianchettos des fous de cases blanches (Fou-g2 vs. Fou-b7)}
translate F PatternDarkFian {Fianchettos des fous de cases noires (Fou-b2 vs. Fou-g7)}
translate F PatternFourFian {Quatre Fianchettos (Fous en b2, g2, b7, g7)}

# Game saving:
translate F Today {Aujourd'hui}
translate F ClassifyGame {Classer la partie}

# Setup position:
translate F EmptyBoard {Vider l'chiquier}
translate F InitialBoard {R-initialiser l'chiquier}
translate F SideToMove {Cot qui a le trait}
translate F MoveNumber {Coup numro}
translate F Castling {Roque}
translate F EnPassantFile {Prise en passant}
translate F ClearFen {Effacer FEN}
translate F PasteFen {Coller FEN}
translate F SaveAndContinue {Enregistrer et continuer}
translate F DiscardChangesAndContinue {Ignorer Changements}
translate F GoBack {Revenir}

# Replace move dialog:
translate F ReplaceMove {Remplacer le coup}
translate F AddNewVar {Ajouter variante}
translate F NewMainLine {Ligne principale}
translate F ReplaceMoveMessage {Un coup existe dj.

Vous pouvez le remplacer, ou bien dtruire tous les coups aprs ce coup ou ajouter une nouvelle variante.

(Vous pouvez demander  ne plus voir ce message  l'avenir, en dslectionnant l'option "Demander avant de remplacer le coup" dans le menu des options)}

# Make database read-only dialog:
translate F ReadOnlyDialog {Si vous mettez cette base en lecture seule, aucun changement ne sera permis.
Aucune partie ne peut tre sauve ou remplace, et aucun drapeau d'effacement ne peut tre altr.
Tout les tris ou les rsultats de classification ECO seront temporaires.

Vous pouvez facilement rendre la base  nouveau accessible en criture, en la fermant et en l'ouvrant  nouveau.

Voulez vous vraiment passer cette base en lecture seule?}

# Exit dialog:
translate F ExitDialog {Voulez-vous rellement quitter Scid?}
translate F ClearGameDialog {Ce jeu a t modifi.\nVoulez-vous le sauvegarder?}
translate F ExitUnsaved {Les bases de donnes suivantes ont des parties modifies non sauvegardes. Si vous quittez maintenant, ces modifications seront perdues.}
translate F ChangeTextDialog {Changer les couleurs du texte ncessite un redmarrage.}
translate F ChangeDockDialog {Changer le mode d'affichage ncessite un redmarrage.}
translate F FontSelectDialog "Ce sont des exemples de texte\nDouble-cliquez dessus pour changer de police, puis choisissez 'ok'\nAaBbCcDdEeFfGgHhIiJjKkLlMm 0123456789. +=-"
translate F ExitNow {Quitter maintenant ?}

# Import window:
translate F PasteCurrentGame {Coller la partie courante}
translate F ImportHelp1 {Entrer ou coller une partie au format PGN dans le cadre ci-dessus.}
translate F ImportHelp2 {Toutes les erreurs durant l'import de la partie seront affiches ici.}
translate F OverwriteExistingMoves {Effacer les coups existants ?}

# ECO Browser:
translate F ECOAllSections {toutes les sections ECO}
translate F ECOSection {section ECO}
translate F ECOSummary {Rsum pour}
translate F ECOFrequency {Frquence des sous-codes pour}

# Opening Report:
translate F OprepTitle {Rapport sur l'ouverture}
translate F OprepReport {Rapport}
translate F OprepGenerated {Gnr par}
translate F OprepStatsHist {Statistiques et Historique}
translate F OprepStats {Statistiques}
translate F OprepStatAll {Toutes les parties du rapport}
translate F OprepStatBoth {Les deux joueurs classs}
translate F OprepStatSince {Depuis}
translate F OprepOldest {Les parties les plus anciennes}
translate F OprepNewest {Les parties les plus rcentes}
translate F OprepPopular {Popularit courante}
translate F OprepFreqAll {Frquence pour toutes les annes: }
translate F OprepFreq1   {Depuis 1 an jusqu' ce jour:      }
translate F OprepFreq5   {Depuis 5 ans jusqu' ce jour:     }
translate F OprepFreq10  {Depuis 10 ans jusqu' ce jour:    }
translate F OprepEvery {une fois toutes les %u parties}
translate F OprepUp {%u%s rencontr pour l'ensemble des annes}
translate F OprepDown {%u%s non rencontr l'ensemble des annes}
translate F OprepSame {sans changement par rapport  l'ensemble des annes}
translate F OprepMostFrequent {Joueurs les plus frquents}
translate F OprepMostFrequentOpponents {Adversaires les plus frquents}
translate F OprepRatingsPerf {Classements et performance}
translate F OprepAvgPerf {Classements moyens et performance}
translate F OprepWRating {Classement des blancs}
translate F OprepBRating {Classement des noirs}
translate F OprepWPerf {Performance des blancs}
translate F OprepBPerf {Performance des noirs}
translate F OprepHighRating {Parties avec le classement moyen le plus lev}
translate F OprepTrends {Tendances de rsultat}
translate F OprepResults {Rsultats longueurs et frquences}
translate F OprepLength {Longueur de partie}
translate F OprepFrequency {Frquence}
translate F OprepWWins {Gains blancs: }
translate F OprepBWins {Gains noirs:  }
translate F OprepDraws {Nulles:       }
translate F OprepWholeDB {base complte}
translate F OprepShortest {Gains les plus rapides}
translate F OprepMovesThemes {Coups et Thmes}
translate F OprepMoveOrders {Ordres de coups atteignant la position du rapport}
translate F OprepMoveOrdersOne \
  {Il n'y a qu'un seul ordre de coups pour atteindre cette position:}
translate F OprepMoveOrdersAll \
  {Il y a %u ordres de coups pour atteindre cette position:}
translate F OprepMoveOrdersMany \
  {Il y a %u ordres de coups pour atteindre cette position. Les %u premiers sont:}
translate F OprepMovesFrom {Coups depuis la position du rapport}
translate F OprepMostFrequentEcoCodes {Codes ECO les plus frquents}
translate F OprepThemes {Thmes positionnels}
translate F OprepThemeDescription {Frquence des thmes dans les premiers %u coups de chaque partie}
translate F OprepThemeSameCastling {Roques du mme ct}
translate F OprepThemeOppCastling {Roques du ct oppos}
translate F OprepThemeNoCastling {Aucun roque}
translate F OprepThemeKPawnStorm {Avalanche de pions  l'aile roi}
translate F OprepThemeQueenswap {Dames changes}
translate F OprepThemeWIQP {Pion Dame blanc isol}
translate F OprepThemeBIQP {Pion Dame noir isol}
translate F OprepThemeWP567 {Pion blanc sur la 5/6/7e range}
translate F OprepThemeBP234 {Pion noir sur la 2/3/4e range}
translate F OprepThemeOpenCDE {Colonne c/d/e ouverte}
translate F OprepTheme1BishopPair {Paire de fous}
translate F OprepEndgames {Finales}
translate F OprepReportGames {Les parties du rapport}
translate F OprepAllGames {Toutes les parties}
translate F OprepEndClass {Classification du matriel des positions finales}
translate F OprepTheoryTable {Table de Thorie}
translate F OprepTableComment {Gnr  partir des %u parties au classement le plus lev.}
translate F OprepExtraMoves {Nombre de coups additionnels dans la table de thorie}
translate F OprepMaxTableGames {Nombre maximum de parties dans la table de thorie}
translate F OprepMaxGames {Nombre maximum de parties pour statistiques}
translate F OprepViewHTML {Voir en HTML}
translate F OprepViewLaTeX {Voir en LaTeX}

# Player Report:
translate F PReportTitle {Rapport du joueur}
translate F PReportColorWhite {avec les Blancs pices}
translate F PReportColorBlack {avec les Noirs pices}
translate F PReportBeginning {Commenant avec}
translate F PReportMoves {aprs %s}
translate F PReportOpenings {Ouvertures}
translate F PReportClipbase {Vider le presse-papier et copier dedans toutes les parties qui correspondent}

# Piece Tracker window:
translate F TrackerSelectSingle {Le bouton gauche de la souris slectionne cette pice.}
translate F TrackerSelectPair {Le bouton gauche de la souris slectionne cette pice; le bouton droit slectionne aussi son pendant.}
translate F TrackerSelectPawn {Le bouton gauche de la souris slectionne ce pion ; le bouton droit slectionne les 8 pions.}
translate F TrackerStat {Statistiques}
translate F TrackerGames {% parties avec dplacement sur la case}
translate F TrackerTime {% fois sur chaque case}
translate F TrackerMoves {Coups}
translate F TrackerMovesStart {Entrer le numro du coups  partir duquel la recherche doit commencer.}
translate F TrackerMovesStop {Entrer le numro du coups auquel la recherche doit s'arrter.}

# Game selection dialogs:
translate F SelectAllGames {Toutes les parties de la base}
translate F SelectFilterGames {Seulement les parties du filtre}
translate F SelectTournamentGames {Seulement les parties du tournoi courant}
translate F SelectOlderGames {Seulement les parties plus anciennes}

# Delete Twins window:
translate F TwinsNote {Pour tre considres comme doublons, deux parties doivent au moins avoir les deux mmes joueurs, et avoir les critres que vous pouvez fixer ci-dessous satisfaits. Quand une paire de doublons est trouve, la partie la plus courte est efface. Conseil: il est prfrable de vrifier l'orthographe dans la base avant d'effacer les doublons, car cela amliore la dtection des doublons. }
translate F TwinsCriteria {Critre: Les doublons doivent avoir...}
translate F TwinsWhich {Parties  examiner}
translate F TwinsColors {Mme couleurs de joueurs?}
translate F TwinsEvent {Mme vnement?}
translate F TwinsSite {Mme lieu?}
translate F TwinsRound {Mme ronde?}
translate F TwinsYear {Mme anne?}
translate F TwinsMonth {Mme mois?}
translate F TwinsDay {Mme jour?}
translate F TwinsResult {Mme rsultat?}
translate F TwinsECO {Mme code ECO?}
translate F TwinsMoves {Mmes coups?}
translate F TwinsPlayers {Comparaison des noms des joueurs:}
translate F TwinsPlayersExact {Correspondance exacte}
translate F TwinsPlayersPrefix {Les 4 premires lettres seules}
translate F TwinsWhen {En effacant les doublons}
translate F TwinsSkipShort {Ignorer toutes les parties de moins de cinq coups?}
translate F TwinsUndelete {Rcuprer toutes les parties d'abord?}
translate F TwinsSetFilter {Appliquer le filtre  tous les doublons limins?}
translate F TwinsComments {Toujours garder les parties qui comportent des commentaires?}
translate F TwinsVars {Toujours garder les parties qui comportent des variantes?}
translate F TwinsDeleteWhich {Partie  effacer:}
translate F TwinsDeleteShorter {La partie la plus courte}
translate F TwinsDeleteOlder {La partie avec le plus petit numro}
translate F TwinsDeleteNewer {La partie avec le plus grand numro}
translate F TwinsDelete {Effacer les parties}

# Name editor window:
translate F NameEditType {Taper le nom  diter}
translate F NameEditSelect {Parties  diter}
translate F NameEditReplace {Remplacer}
translate F NameEditWith {avec}
translate F NameEditMatches {Correspondances: Presser Alt+1  Alt+9 pour slectionner}
translate F MatchPattern {Positions corespondantes}

# Classify window:
translate F Classify {Classer}
translate F ClassifyWhich {Choix des parties  classer suivant ECO}
translate F ClassifyAll {Toutes les parties (crase les anciens codes ECO)}
translate F ClassifyYear {Toutes les parties joues la dernire anne}
translate F ClassifyMonth {Toutes les parties joues le dernier mois}
translate F ClassifyNew {Seulement les parties qui ne possdent pas encore de code ECO}
translate F ClassifyCodes {Codes ECO  utiliser}
translate F ClassifyBasic {Codes de base seulement ("B12", ...)}
translate F ClassifyExtended {Extensions de Scid ("B12j", ...)}

# Compaction:
translate F NameFile {Fichier de noms}
translate F GameFile {Fichier de parties}
translate F Names {Noms}
translate F Unused {Non utilis}
translate F SizeKb {Taille (kb)}
translate F CurrentState {tat courant}
translate F AfterCompaction {Aprs compactage}
translate F CompactNames {Compacter le fichier de noms}
translate F CompactGames {Compacter le fichier de parties}
translate F NoUnusedNames "Il n'y a pas de noms inutiliss, le fichier de noms est donc dj compact."
translate F NoUnusedGames "Le fichier des parties est dj compact."
translate F NameFileCompacted {Le fichier de noms de la base "[file tail [sc_base filename]]" a t compact.}
translate F GameFileCompacted {Le fichier de parties de la base "[file tail [sc_base filename]]" a t compact.}

# Sorting:
translate F SortCriteria {Critre}
translate F AddCriteria {Ajouter un critre}
translate F CommonSorts {Tris courants}
translate F Sort {Tri}

# Exporting:
translate F AddToExistingFile {Ajouter les parties  un fichier existant?}
translate F ExportComments {Exporter les commentaires?}
translate F ExportVariations {Exporter les variantes?}
translate F IndentComments {Indenter les commentaires?}
translate F IndentVariations {Indenter les variantes?}
translate F InsertNewlines {Passez  la ligne aprs 80 cars?}
translate F ExportColumnStyle {Style en colonne (un coup par ligne)?}
translate F ExportSymbolStyle {Style d'annotation symbolique:}
translate F ExportStripMarks {Enlever les codes de marquages de flches et de coloration de cases des commentaires?}
translate F ExportFlags {Exporter les drapeaux}

# Goto game/move dialogs:
translate F LoadGameNumber {Entrer le numro de la partie  charger:}
translate F GotoMoveNumber {Aller au coup numro:}

# Copy games dialog:
translate F CopyGames {Copier les parties}
translate F CopyConfirm {
 Voulez vous vraiment copier
 les [::utils::thousands $nGamesToCopy] parties filtres
 depuis la base "$fromName"
 vers la base "$targetName"?
}
translate F CopyErr {Ne peut copier les parties}
translate F CopyErrSource {la base source}
translate F CopyErrTarget {la base destination}
translate F CopyErrNoGames {n'a pas de parties dans son filtre}
translate F CopyErrReadOnly {est en lecture seule}
translate F CopyErrNotOpen {n'est pas ouverte}

# Colors:
translate F LightSquares {Cases blanches}
translate F DarkSquares {Cases noires}
translate F SelectedSquares {Cases slectionnes}
translate F SelectedOutline {Bordure case slectionne}
translate F SuggestedSquares {Suggres}
translate F Grid {Grille}
translate F Previous {Prcdents}
translate F WhitePieces {Pices blanches}
translate F BlackPieces {Pices noires}
translate F WhiteBorder {Bordure des pices blanches}
translate F BlackBorder {Bordure des pices noires}
translate F ArrowMain   {Flche principale}
translate F ArrowVar    {Flches variantes}
translate F ShowArrows  {Montrer les flches}

# Novelty window:
translate F FindNovelty {Trouver la nouveaut}
translate F Novelty {Nouveaut}
translate F NoveltyInterrupt {Recherche de nouveaut interrompue}
translate F NoveltyNone {Aucune nouveaut n'a t trouve pour cette partie}
translate F NoveltyHelp {
Scid va trouver le premier coup de la partie en cours qui atteint une position qui ne figure ni dans la base slectionne ni dans le rpertoire d'ouvertures ECO.
}

# Sounds configuration:
translate F SoundsFolder {Rpertoire des fichiers sonores}
translate F SoundsFolderHelp {Le rpertoire devrait contenir les fichiers King.wav, a.wav, 1.wav, etc}
translate F SoundsAnnounceOptions {Options d'annonce des coups}
translate F SoundsAnnounceNew {Annoncer les coups jous}
translate F SoundsAnnounceForward {Annoncer les coups quand avance d'un coup}
translate F SoundsAnnounceBack {Annoncer quand retour arrire d'un coup}

# Upgrading databases:
translate F Upgrading {Mise  jour}
translate F ConfirmOpenNew {
Ceci est une base de donnes  l'ancien format (Scid 2) qui ne peut tre ouverte dans Scid 3, mais une version au nouveau format (Scid 3) a dj t cre.

Voulez vous ouvrir le nouveau format de la base de donnes?
}
translate F ConfirmUpgrade {
Ceci est une base de donnes  l'ancien format (Scid 2). Une version de la base de donnes au nouveau format doit tre cre avant de pouvoir tre utilise dans Scid 3.

Mettre  jour va crer une nouvelle version de la base de donnes; les fichiers originaux ne seront pas dits ou effacs.

Cela peut prendre un peu de temps, mais il n'est ncessaire de le faire qu'une fois. Vous pouvez abandonner si cela dure trop longtemps.

Voulez vous mettre  jour cette base de donnes maintenant?
}

# Recent files options:
translate F RecentFilesMenu {Nombre de fichiers rcents dans le menu Fichier}
translate F RecentFilesExtra {Nombre de fichiers rcents dans le sous-menu complmentaire}

# My Player Names options:
translate F MyPlayerNamesDescription {
Entrer ci-dessous une liste des noms des joueurs prfrs, un nom par ligne. Les caractres spciaux (i.e. "?" pour un seul caractre, "*" pour n'importe quelle suite de caractres) sont autoriss.

Chaque fois qu'une partie avec un joueur de la liste est charge, l'chiquier de la fentre principale sera tourn si ncessaire de faon  montrer la partie selon le point de vue du joueur.
}
#Coach
translate F showblunderexists {Montrer si erreur}
translate F showblundervalue {Montrer la valeur de l'erreur}
translate F showscore {Montrer score}
translate F coachgame {Entrainement}
translate F configurecoachgame {Configurer une partie avec entraineur}
translate F configuregame {Configuration de partie}
translate F Phalanxengine {moteur Phalanx}
translate F Coachengine {entraineur}
translate F difficulty {difficult}
translate F hard {difficile}
translate F easy {facile}
translate F Playwith {Jouer avec}
translate F white {blanc}
translate F black {noir}
translate F both {les deux}
translate F Play {Jouer}
translate F Noblunder {Pas d'erreur}
translate F blunder {erreur}
translate F Noinfo {-- Pas d'info --}
translate F moveblunderthreshold {le coup est une erreur si les pertes sont suprieures }
translate F limitanalysis {limiter le temps d'analyse}
translate F seconds {secondes}
translate F Abort {Arrter}
translate F Quit {Quitter}
translate F Resume {Reprendre}
translate F Restart {Recommencer}
translate F OutOfOpening {Hors de l'ouverture}
translate F NotFollowedLine {Vous n'avez pas suivi la ligne}
translate F DoYouWantContinue {Voulez-vous continuer ?}
translate F CoachIsWatching {L'entraineur regarde}
translate F Ponder {Rflexion permanente}
translate F LimitELO {Limiter force ELO}
translate F DubiousMovePlayedTakeBack {Coup douteux jou, voulez-vous reprendre le coup ?}
translate F WeakMovePlayedTakeBack {Coup faible jou, voulez-vous reprendre le coup ?}
translate F BadMovePlayedTakeBack {Mauvais coup jou, voulez-vous reprendre le coup ?}
translate F Iresign {J'abandonne}
translate F yourmoveisnotgood {Votre coup n'est pas bon}
translate F EndOfVar {Fin de variante}
translate F Openingtrainer {Entrainement aux ouvertures}
translate F DisplayCM {Afficher les coups candidats}
translate F DisplayCMValue {Afficher la valeur des coups candidats}
translate F DisplayOpeningStats {Montrer statistiques}
translate F ShowReport {Montrer rapport}
translate F NumberOfGoodMovesPlayed {bons coups jous}
translate F NumberOfDubiousMovesPlayed {coups douteux jous}
translate F NumberOfTimesPositionEncountered {nombre de fois position rencontre}
translate F PlayerBestMove  {N'autoriser que les meilleurs coups}
translate F OpponentBestMove {Ne jouer que les meilleurs coups}
translate F OnlyFlaggedLines {Seulement les lignes marques}
translate F resetStats {Remettre  zro les scores}
translate F Movesloaded {Coups lus}
translate F PositionsNotPlayed {Positions non joues}
translate F PositionsPlayed {Positions joues}
translate F Success {Succs}
translate F DubiousMoves {Coups douteux}
translate F ConfigureTactics {Configurer exercices tactiques}
translate F ResetScores {Remise  zro des scores}
translate F LoadingBase {Chargement de la base}
translate F Tactics {Tactique}
translate F ShowSolution {Montrer la solution}
translate F Next {Suivant}
translate F ResettingScore {Remise  zro des scores}
translate F LoadingGame {Chargement partie}
translate F MateFound {Mat trouv}
translate F BestSolutionNotFound {Meilleur coup non trouv !}
translate F MateNotFound {Mat non trouv}
translate F ShorterMateExists {Un mat plus rapide existe}
translate F ScorePlayed {score coup jou}
translate F Expected {attendu}
translate F ChooseTrainingBase {Choisir la base d'exercices}
translate F Thinking {Calcul en cours}
translate F AnalyzeDone {Analyse termine}
translate F WinWonGame {Terminer partie gagne}
translate F Lines {Lignes}
translate F ConfigureUCIengine {Configurer moteur UCI}
translate F SpecificOpening {Ouverture spcifique}
translate F ImportECO {Importer ECO}
translate F StartNewGame {Nouvelle partie}
translate F FixedLevel {Niveau fixe}
translate F Opening {Ouverture}
translate F RandomLevel {Niveau alatoire}
translate F StartFromCurrentPosition {Jouer depuis la position actuelle}
translate F FixedDepth {Profondeur fixe}
translate F Nodes {Noeuds} 
translate F Depth {Profondeur}
translate F Time {Temps} 
translate F Auto {Auto}
translate F Score {Score}
translate F {Score Combo} {Score Combin}
translate F {Time Combo} {Time Combin}
translate F SecondsPerMove {Secondes par coup}
translate F DepthPerMove {Profondeur par coup}
translate F MoveControl {Type d'analyse}
translate F TimeLabel {Time per move}
translate F AddVars {Ajouter les variantes}
translate F AddScores {Additionner scores}
translate F Engine {Moteur}
translate F TimeMode {Mode de rflexion}
translate F TimeBonus {Temps + bonus}
translate F TimeMin {min}
translate F TimeSec {sec}
translate F AllExercisesDone {Tous les exercices sont faits}
translate F MoveOutOfBook {Coup hors bibliothque d'ouverture}
translate F LastBookMove {Dernier coup de la bibliothque d'ouverture}
translate F AnnotateSeveralGames {Annotater plusieurs parties}
translate F FindOpeningErrors {Chercher les erreurs d'ouverture}
translate F MarkTacticalExercises {Marquer exercices tactiques}
translate F UseBook {Utiliser bibliothque}
translate F MultiPV {Nombre de variantes}
translate F Hash {Mmoire}
translate F OwnBook {Utiliser bibliothque propre}
translate F BookFile {Bibliothque d'ouverture}
translate F AnnotateVariations {Annotater les variantes}
translate F ShortAnnotations {Annotations courtes}
translate F addAnnotatorTag {Ajouter Annotateur}
translate F AddScoreToShortAnnotations {Ajouter score aux annotations courtes}
translate F Export {Exporter}
translate F BookPartiallyLoaded {Bibliothque charge en partie}
translate F AddLine {Ajouter ligne}
translate F RemLine {Enlever ligne}
translate F Calvar {Calcul de variantes}
translate F ConfigureCalvar {Configuration}
# Opening names used in tacgame.tcl
translate F Reti {Reti}
translate F English {Anglaise}
translate F d4Nf6Miscellaneous {1.d4 Cf6 divers}
translate F Trompowsky {Trompowsky}
translate F Budapest {Budapest}
translate F OldIndian {Vieille Indienne}
translate F BenkoGambit {Gambit Benko}
translate F ModernBenoni {Benoni Moderne}
translate F DutchDefence {Dfense hollandaise}
translate F Scandinavian {Scandinave}
translate F AlekhineDefence {Dfense Alekhine}
translate F Pirc {Pirc}
translate F CaroKann {Caro-Kann}
translate F CaroKannAdvance {Caro-Kann Avance}
translate F Sicilian {Sicilienne}
translate F SicilianAlapin {Sicilienne Alapin}
translate F SicilianClosed {Sicilienne ferme}
translate F SicilianRauzer {Sicilienne Rauzer}
translate F SicilianDragon {Sicilienne Dragon}
translate F SicilianScheveningen {Sicilienne Scheveningen}
translate F SicilianNajdorf {Sicilienne Najdorf}
translate F OpenGame {Partie ouverte}
translate F Vienna {Viennoise}
translate F KingsGambit {Gambit Roi}
translate F RussianGame {Petroff}
translate F ItalianTwoKnights {Italienne/Deux cavaliers}
translate F Spanish {Espagnole}
translate F SpanishExchange {Espagnole change}
translate F SpanishOpen {Espagnole ouverte}
translate F SpanishClosed {Espagnole ferme}
translate F FrenchDefence {Dfense franaise}
translate F FrenchAdvance {Dfense franaise Avance}
translate F FrenchTarrasch {Dfense franaise Tarrasch}
translate F FrenchWinawer {Dfense franaise Winawer}
translate F FrenchExchange {Dfense franaise Echange}
translate F QueensPawn {Pion Dame}
translate F Slav {Slave}
translate F QGA {GD Accept}
translate F QGD {GD Dclin}
translate F QGDExchange {GD Echange}
translate F SemiSlav {Semi-Slave}
translate F QGDwithBg5 {GD dclin avec Fg5}
translate F QGDOrthodox {GD dclin Orthodoxe}
translate F Grunfeld {Grnfeld}
translate F GrunfeldExchange {Grnfeld Echange}
translate F GrunfeldRussian {Grnfeld Russe}
translate F Catalan {Catalane}
translate F CatalanOpen {Catalane Ouverte}
translate F CatalanClosed {Catalane Ferme}
translate F QueensIndian {Ouest indienne}
translate F NimzoIndian {Nimzo-Indienne}
translate F NimzoIndianClassical {Nimzo-Indienne Classique}
translate F NimzoIndianRubinstein {Nimzo-Indienne Rubinstein}
translate F KingsIndian {Est-indienne}
translate F KingsIndianSamisch {Est-indienne Smisch}
translate F KingsIndianMainLine {Est-indienne ligne principale}

translate F ConfigureFics {Configurer FICS}
translate F FICSLogin {Login}
translate F FICSGuest {Login comme invit}
translate F FICSServerPort {Port du serveur}
translate F FICSServerAddress {Adresse IP}
translate F FICSRefresh {Rafrachir}
translate F FICSTimeseal {Timeseal}
translate F FICSTimesealPort {Port Timeseal}
translate F FICSSilence {Silence}
translate F FICSOffers {Offres}
translate F FICSMakeOffer {Faire une Offre}
translate F FICSGames {Parties}
translate F FICSFindOpponent {Trouver adversaire}
translate F FICSTakeback {Reprendre un coup}
translate F FICSTakeback2 {Rependre deux coups}
translate F FICSInitTime {Temps initial (min)}
translate F FICSIncrement {Incrment (sec)}
translate F FICSRatedGame {Partie classe}
translate F FICSAutoColour {automatique}
translate F FICSManualConfirm {accepter manuellement}
translate F FICSFilterFormula {Filtrer avec formule}
translate F FICSIssueSeek {Envoyer seek}
translate F FICSAccept {accepter}
translate F FICSDecline {refuser}
translate F FICSColour {Couleur}
translate F FICSSend {envoyer}
translate F FICSConnect {Connecter}
translate F FICSShouts {Cris}
translate F FICSTells {Dire}
translate F FICSOpponent {Informations de l'adversaire}
translate F FICSInfo {Informations}
translate F FICSDraw {Proposer la nulle}
translate F FICSRematch {Revanche}
translate F FICSQuit {Quitter}
translate F FICSCensor {Censurer}

translate F CCDlgConfigureWindowTitle {Configurer checs par correspondance}
translate F CCDlgCGeneraloptions {Options gnrales}
translate F CCDlgDefaultDB {Base par dfaut:}
translate F CCDlgInbox {Rception (chemin):}
translate F CCDlgOutbox {Envoi (chemin):}
translate F CCDlgXfcc {Configuration Xfcc:}
translate F CCDlgExternalProtocol {Protocole externe (p.e. Xfcc)}
translate F CCDlgFetchTool {Outil de rception:}
translate F CCDlgSendTool {Outil d'envoi:}
translate F CCDlgEmailCommunication {Communication eMail}
translate F CCDlgMailPrg {Programme de mail:}
translate F CCDlgBCCAddr {Addresse de copie:}
translate F CCDlgMailerMode {Mode:}
translate F CCDlgThunderbirdEg {p.e. Thunderbird, Mozilla Mail, Icedove...}
translate F CCDlgMailUrlEg {p.e. Evolution}
translate F CCDlgClawsEg {p.e Sylpheed Claws}
translate F CCDlgmailxEg {p.e. mailx, mutt, nail...}
translate F CCDlgAttachementPar {Attachement:}
translate F CCDlgInternalXfcc {Utiliser Xfcc interne}
translate F CCDlgConfirmXfcc {Confirmer coups}
translate F CCDlgSubjectPar {Objet:}
translate F CCDlgDeleteBoxes {Vider botes}
translate F CCDlgDeleteBoxesText {Voulez-vous rellement vider les botes entrantes et sortantes pour les checs par correspondance ? Cela ncessite une nouvelle synchronisation pour afficher le dernier tat de vos parties}
translate F CCDlgConfirmMove {Confirmer coup}
translate F CCDlgConfirmMoveText {Si vous confirmez, le coup ci-dessous et le commentaire sont envoys au serveur:}
translate F CCDlgDBGameToLong {Ligne principale incohrente}
translate F CCDlgDBGameToLongError {La ligne principale dans votre base de donnes est plus longue que la partie dans votre bote de rception. Si la bote de rception contient les parties en cours, c'est--dire juste aprs une synchronisation, certains coups ont t ajouts  tort  la ligne principale dans la base de donnes.\nDans ce cas veuillez raccourcir la ligne principale  au plus coup\n}
translate F CCDlgStartEmail {Commencer nouvelle partie par eMail}
translate F CCDlgYourName {Votre nom:}
translate F CCDlgYourMail {Votre adresse mail:}
translate F CCDlgOpponentName {Nom adversaire:}
translate F CCDlgOpponentMail {Adresse eMail adversaire:}
translate F CCDlgGameID {Identifiant Partie (unique):}
translate F CCDlgTitNoOutbox {Scid: Bote d'envoi}
translate F CCDlgTitNoInbox {Scid: Bote de rception}
translate F CCDlgTitNoGames {Scid: Pas de parties par correspondence}
translate F CCErrInboxDir {Rpertoire de la bote de rception:}
translate F CCErrOutboxDir {Rpertoire de la bote d'envoi:}
translate F CCErrDirNotUsable {n'existe pas ou inaccessible!\nVeuillez vrifier les paramtres.}
translate F CCErrNoGames {ne contient pas de parties!\nVeuillez d'abord les rcuprer.}
translate F CCDlgTitNoCCDB {Scid: pas de base par correspondance}
translate F CCErrNoCCDB {Aucune base du type 'Correspondance' n'est ouverte. Ouvrez-en une avant d'utiliser les fonctions par correspondance.}
translate F CCFetchBtn {Rcuprer les parties sur le serveur et les analyser dans la bote de rception}
translate F CCPrevBtn {Aller  la partie prcdente}
translate F CCNextBtn {Aller  la partie suivante}
translate F CCSendBtn {Envoyer coup}
translate F CCEmptyBtn {Vider les botes d'envoi et de rception}
translate F CCHelpBtn {Aide sur les icnes et indicateurs.\nPour plus d'aide appuyer sur F1!}
translate F CCDlgServerName {Nom serveur:}
translate F CCDlgLoginName  {Login:}
translate F CCDlgPassword   {Mot de passe:}
translate F CCDlgURL        {Xfcc-URL:}
translate F CCDlgRatingType {Type classement:}
translate F CCDlgDuplicateGame {Identifiant de partie non-unique}
translate F CCDlgDuplicateGameError {Cette partie existe  plusieurs exemplaires dans la base de donnes. Veuillez effacer tous les doublons et compacter votre fichier de parties (Fichier/Maintenance/Compacter base).}
translate F CCDlgSortOption {Tri:}
translate F CCDlgListOnlyOwnMove {Parties o c'est mon tour}
translate F CCOrderClassicTxt {Site, Evnement, Ronde, Rsultat, Blancs, Noirs}
translate F CCOrderMyTimeTxt {Ma pendule}
translate F CCOrderTimePerMoveTxt {Temps par coup jusqu'au prochain contrlede temps}
translate F CCOrderStartDate {Date de dpart}
translate F CCOrderOppTimeTxt {Pendule adversaire}
translate F CCDlgConfigRelay {Configurer observations ICCF}
translate F CCDlgConfigRelayHelp {Aller  la page des parties sur http://www.iccf-webchess.com et afficher la partie que vous aimez observer. Si vouz voyez l'chiquier, copiez l'URL de votre navigateur  la liste ci-dessous. Seule une URL par ligne !\nPar exemple: http://www.iccf-webchess.com/MakeAMove.aspx?id=266452}

translate F ExtHWConfigConnection {Configurer hardware extrieur}
translate F ExtHWPort {Port}
translate F ExtHWEngineCmd {Commande du moteur}
translate F ExtHWEngineParam {Paramtre du moteur}
translate F ExtHWShowButton {Montrer bouton}
translate F ExtHWHardware {Hardware}
translate F ExtHWNovag {Novag Citrine}
translate F ExtHWInputEngine {Autre priphrique}
translate F ExtHWNoBoard {Pas de plateau}
translate F IEConsole {Console priphrique}
translate F IESending {Les coups ont t envoys par}
translate F IESynchronise {Synchroniser}
translate F IERotate  {Retourner}
translate F IEUnableToStart {Echec du dmarrage priphrique:}
translate F DoneWithPosition {Position termine}
translate F Board {Echiquier}
translate F showGameInfo {Montrer le panneau d'info}
translate F autoResizeBoard {Redimensionnement automatique}
translate F DockTop {Dplacer en haut}
translate F DockBottom {Dplacer en bas}
translate F DockLeft {Dplacer  gauche}
translate F DockRight {Dplacer  droite}
translate F Undock {Dtacher}
translate F ChangeIcon {Changer icone}
translate F More {Plus...}

# Drag & Drop
translate F CannotOpenUri {Ouverture impossible de l'URI:}
translate F InvalidUri {Les donnes dposes sont sans URI valide}
translate F UriRejected	{Les fichiers suivant sont rejets:}
translate F UriRejectedDetail {Seuls les types de fichiers lists seront grs:}
translate F EmptyUriList {Le contenu dpos est vide.}
translate F SelectionOwnerDidntRespond {Timeout durant l'envoi: absence de rponse.}
translate F PasteAnal {Coller l'analyse}
translate F SortOpcodes {Tri des Opcodes}
translate F AddPosition {Ajout d'une position}
translate F FindPos {Recherche position profonde}
translate F AnalPosition {Analyse des positions}
translate F StripOpcodes {limination des Opcodes}
translate F NoMoves {Dplacement interdit depuis position}
translate F CountBestMoves {Compteur des meilleurs dplacements}

##########
#
# ECO Opening name translations:

# translateECO F 
  # Accelerated {, Acclr}
  # {: Accelerated} Acclr
  # Accepted {, accept}
  # {: Accepted} Accept
  # Advance Avance
  # {as Black} {avec les Noirs}
  # Attack Attaque
  # Bishop Fou
  # Bishop's Fou
  # Classical Classique
  # Closed Ferm
  # {Closed System} {Systme ferm}
  # Counterattack Contre-Attaque
  # Countergambit Contre-Gambit
  # Declined {, Dclin}
  # Defence Dfense
  # deferred diffr
  # Deferred {, Diffr}
  # Early Tt
  # Exchange Echange
  # Game Partie
  # Improved amlior
  # King's Roi
  # Knight Cavalier
  # Line Ligne
  # {Main Line} Ligne principale
  # Open Ouvert
  # Opening Ouverture
  # Queen's Dame
  # Queenswap Permutation de dame
  # Symmetrical Symtrique
  # Variation Variante
  # Wing Aile
  # with avec
  # without sans
  # 
  # Alekhine Alekhine
  # Averbakh Averbakh
  # Botvinnik Botvinnik
  # Chigorin Tchigorine
  # Polugaevsky Polugaevsky
  # Rauzer Rauzer
  # Sveshnikov Sveshnikov
  # 
  # Austrian Autrichien
  # Berlin Berlinois
  # Bremen Breme
  # Catalan Catalane
  # Czech Tchque
  # Dutch Hollandaise
  # English Anglaise
  # French Franaise
  # Hungarian Hongroise
  # Indian Indienne
  # Italian Italienne
  # Latvian Letton
  # Meran Meran
  # Moscow Moscou
  # Polish Polonais
  # Prague Prague
  # Russian Russe
  # Scandinavian Scandinave
  # Scheveningen Scheveningen
  # Scotch Ecossaise
  # Sicilian Sicilienne
  # Slav Slave
  # Spanish Espagnole
  # Swedish Sudois
  # Swiss Suisse
  # Vienna Viennois
  # Yugoslav Yougoslave
  # 
  # {Accelerated Fianchetto} {Fianchetto Acclr}
  # {Accelerated Pterodactyl} {Pterodactyle Acclr}
  # {Alekhine Defence} Dfense-Alekhine
  # {Alekhine Variation} Variante-Alekhine
  # {Alekhine: Smisch Attack} {Alekhine: Systme viennois (Attaque Smisch)}
  # {Anderssen Opening} Ouverture-Anderssen
  # {Anti-King's Indian} Anti-Est-Indienne
  # {Austrian Attack} {Attaque Autrichienne}
  # {Benko Gambit} {Gambit Benko}
  # {Benko Opening} {Ouverture Benk}
  # {Berlin Defence} {Dfense Berlinoise}
  # Chameleon Cameleon
  # Chelyabinsk Chelyabinsk
  # {Classical Defence} {Dfense Classique}
  # {Spanish: Classical Defence} {Espagnole: Dfense Classique}
  # {Classical Exchange} {Echange Classique}
  # {Classical Variation} {Variante Classique}
  # {Closed Berlin} {Berlinoise Ferme}
  # {Open Berlin} {Berlinoise Ouverte}
  # {Bird's,} {Bird,}
  # {Bird's Defence} {Dfense Bird}
  # {Bird's Deferred} {Bird Diffre}
  # {Bishop's Opening} {Ouverture du Fou}
  # {Botvinnik System} {Systme Botvinnik}
  # {Central Variation} {Variante du centre}
  # {Centre Attack} {Attaque du centre}
  # {Centre Game} {Ouverture du centre}
  # {Danish Gambit} {Gambit Danois}
  # Dragon Dragon
  # {Dutch Variation} {Variante Hollandaise}
  # {Early Exchange} {Echange rapide}
  # {Early Queenswap} {Echange de Dames rapide}
  # {English Attack} {Attaque Anglaise}
  # {English: King's} {Anglaise: Roi}
  # {English Variation} {Variante Anglaise}
  # {Englund Gambit} {Gambit Englund}
  # {Exchange Variation} {Variante d'change}
  # {Fianchetto Variation} {Variante du Fianchetto}
  # {Flohr Variation} {Variante Flohr}
  # {Four Knights} {Quatre Cavaliers}
  # {Four Knights Game} {Partie des Quatre Cavaliers}
  # {Four Pawns} {Quatre Pions}
  # {Four Pawns Attack} {Attaque des Quatre Pions}
  # {French Variation} {Variante Franaise}
  # {From Gambit} {Gambit From}
  # {Goring Gambit} {Gambit Gring}
  # {Grob Gambit} {Gambit Grob}
  # {Hungarian Defence} {Dfense Hongroise}
  # {Indian Variation} {Variante Indienne}
  # {Italian Game} {Partie Italienne}
  # KGD {Gambit Roi Dclin}
  # {Classical KGD} {Gambit Roi Dclin Classique}
  # {Keres Variation} {Variante Keres}
  # KGA {Gambit Roi Accept}
  # {KGA: Bishop's Gambit} {Gambit Roi Accept: Gambit du Fou}
  # {KGA: King's Knight Gambit} {Gambit Roi Accept: Gambit du Cavalier}
  # {King's Gambit} {Gambit Roi}
  # {King's Gambit Accepted} {Gambit Roi Accept}
  # {King's Gambit Accepted (KGA)} {Gambit Roi Accept}
  # {King's Indian} Est-Indienne
  # KIA {Attaque Est-Indienne}
  # {King's Knight Gambit} {Gambit du Cavalier Roi}
  # {King's Pawn} {Pion Roi}
  # {Lasker Variation} {Variante Lasker}
  # {Latvian Gambit} {Gambit Letton}
  # {Maroczy Bind} {Maroczy}
  # {Marshall Variation} {Variante Marshall}
  # {Modern Attack} {Attaque Moderne}
  # {Modern Steinitz} {Steinitz Moderne}
  # {Modern Variation} {Variante Moderne}
  # {Moscow Variation} {Variante de Moscou}
  # Nimzo-Indian Nimzo-Indienne
  # {Old Benoni} {Vieille Benoni}
  # {Old Indian} {Vieille Indienne}
  # {Old Indian Attack} {Attaque Vieille Indienne}
  # {Old Steinitz} {Vieille Steinitz}
  # {Open Game} {Partie Ouverte}
  # {Poisoned Pawn} {Pion empoisonn}
  # {Polish Variation} {Variante Polonaise}
  # {Polugaevsky Variation} {Variante Polugajewski}
  # {Queen's Gambit} {Gambit Dame}
  # {Queen's Gambit Accepted} {Gambit Dame accept}
  # QGA {GDA}
  # {Queen's Gambit Accepted (QGA)} {Gambit Dame accept (GDA)}
  # {Reversed QGA} {GDA invers}
  # QGD {Gambit Dame Dclin}
  # {Queen's Gambit Declined (QGD)} {Gambit Dame Dclin (GDD)}
  # {Reversed QGD} {GDD invers}
  # {Queen's Indian} Ouest-Indienne
  # {Queen's Pawn} {Pion Dame}
  # {Queen's Pawn Game} {Partie du Pion Dame}
  # {Reversed Slav} {Slave Inverse}
  # {Rubinstein Variation} {Variante Rubinstein}
  # {Russian Game} {Partie Russe}
  # {Russian Game (Petroff Defence)} {Partie Russe (Dfense Petrov)}
  # {Russian-Three Knights Game} {Partie Russe: Trois Cavaliers}
  # {Scandinavian (Centre Counter)} {Scandinave (Centre)}
  # Schliemann Jnisch
  # {Schliemann (Jnisch)} {Gambit Jnisch (Schliemann)}
  # {Scotch Opening} {Ouverture Ecossaise}
  # {Sicilian Defence} {Dfense Sicilienne}
  # {Sicilian Variation} {Variante Sicilienne}
  # {Slav Defence} {Dfense Slave}
  # Smith-Morra Morra
  # {Smith-Morra Accepted} {Gambit Morra Accept}
  # {Smith-Morra Gambit} {Gambit Morra}
  # {Spanish (Ruy Lopez)} {Partie Espagnole}
  # {Start position} {Position de dpart}
  # {Steinitz Deferred} {Rubinstein retarde}
  # {Swedish Variation} {Variante sudoise}
  # {Swiss Variation} {Variante Suisse}
  # {Tarrasch's Gambit} {Gambit Tarrasch}
  # {Three Knights} {Trois Cavaliers}
  # {3 Knights} {Trois Cavaliers}
  # {Three Knights Game} {Partie des Trois Cavaliers}
  # {Three Pawns Attack} {Attaque des Trois Pions}
  # {Two Knights} {Deux Cavaliers}
  # {Two Knights Defence} {Dfense des Deux Cavaliers}
  # {Two Knights Variation} {Variante des Deux Cavaliers}
  # {Two Pawns} {Deux Pions}
  # {Two Pawns Attack} {Attaque des Deux Pions}
  # {Wing Gambit} {Gambit de l'aile}
  # {Yugoslav Attack} {Attaque Yougoslave}


}

# end of francais.tcl
